/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent;

/**
 * Interface for all constants that should be globally accessible and are
 * specific to our team
 * @author Klaus Dorer
 */
@SuppressWarnings("all")
public interface IMagmaConstants
{
	/** the default name of the own team */
	String DEFAULT_TEAMNAME = "magmaOffenburg";

	/** the number of players that play at most in one team */
	int NUMBER_OF_PLAYERS_PER_TEAM = 11;

	/** constant used to identify the id of a player that is not known */
	int UNKNOWN_PLAYER_NUMBER = -1;

	/** constant used to identify the team name of a player that is not known */
	String UNKNOWN_PLAYER_TEAMNAME = "";

	/** positions the agents beam to before start if playing from left to right */
	float[][] startPositionsOwnKickoff = { { -0.17f, -0.05f, 0.0f }, // default
			{ -10.0f, 0.0f, 0.0f }, // goalie
			{ -7.0f, 1.8f, 0.0f }, // 2
			{ -6.5f, 0.0f, 0.0f }, // 3
			{ -7.0f, -1.8f, 0.0f }, // 4
			{ -4.0f, 2f, 0.0f }, // 5
			{ -3.0f, 0.0f, 0.0f }, // 6
			{ -4.0f, -2f, 0.0f }, // 7
			{ -1.0f, 1.0f, 0.0f }, // 8
			{ -0.17f, -0.05f, 0.0f }, // 9
			{ -8.0f, 2.5f, 0.0f }, // 10
			{ -8.0f, -2.5f, 0.0f } // 11
	};

	/** positions the agents beam to before start if playing from right to left */
	float[][] startPositionsOtherKickoff = { { -1.5f, 0.0f, 0.0f }, // default
			{ -10.0f, 0.0f, 0.0f }, // goalie
			{ -7.0f, 1.8f, 0.0f }, // 2
			{ -6.5f, 0.0f, 0.0f }, // 3
			{ -7.0f, -1.8f, 0.0f }, // 4
			{ -4.0f, 2f, 0.0f }, // 5
			{ -3.0f, 0.0f, 0.0f }, // 6
			{ -4.0f, -2f, 0.0f }, // 7
			{ -2.0f, 1.0f, 0.0f }, // 8
			{ -2.0f, -1.0f, 0.0f }, // 9
			{ -8.0f, 2.5f, 0.0f }, // 10
			{ -8.0f, -2.5f, 0.0f } // 11
	};

	/**
	 * positions the agents beam to before start if playing from left to right
	 * used in 2009
	 */
	float[][] startPositionsOwnKickoff_VERSION62 = { { -0.17f, -0.05f, -5.0f },
			{ -5.5f, 0.0f, 0.0f }, // goalie
			{ -4.0f, 0.0f, 0.0f }, // 2
			{ -0.17f, -0.05f, -5.0f }, // 3
			{ -1.5f, 2.0f, 0.0f } // 4
	};

	/**
	 * positions the agents beam to before start if playing from right to left
	 * used in 2009
	 */
	float[][] startPositionsOtherKickoff_VERSION62 = { { -1.5f, 0.0f, 0.0f },
			{ -5.5f, 0.0f, 0.0f }, // goalie
			{ -4.0f, 0f, 0.0f }, // 2
			{ -1.5f, 0.5f, 0.0f }, // 3
			{ -0.0f, 2.0f, 0.0f } // 4
	};

	double DISTANCE_PENALTY_LYING = 3;

	float TIMEDELAY_LAYING = 4;
}
