/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.action.impl;

/**
 * Implementation of the SimSpark "HingeJoint" effector, used to move robot
 * joints
 * 
 * @author Klaus Dorer
 */
public class HingeEffector extends Effector
{
	private float speed; // zero no change of the angle

	private float last_speed; // zero no change of the angle

	/**
	 * Instantiates a new HingeJoint effector and initializes all fields to zero
	 * 
	 * @param name Hinge Joint name
	 */
	public HingeEffector(String name)
	{
		super(name);

		setAxisSpeed(0.0f);
		last_speed = 0.0f;
	}

	/**
	 * Set axis speed
	 * 
	 * @param speed New speed
	 */
	public void setAxisSpeed(float speed)
	{
		this.speed = speed;
	}

	@Override
	public String getMessageString()
	{
		String msg = "";

		if (speed != last_speed) {
			StringBuilder buffer = new StringBuilder(30);

			buffer.append("(").append(getName());
			buffer.append(" ").append(speed).append(")");

			msg = buffer.toString();

			last_speed = speed;
		}
		speed = 0.0f;

		return msg;
	}
}
