/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.agentmodel;

import javax.vecmath.Vector3d;

/**
 * 
 * @author dorer
 */
public interface IBodyModel
{
	/**
	 * @param name the name of the sensor to return
	 * @return the first sensor in a body part that is found having passed name
	 */
	ISensor getSensor(String name);

	/**
	 * @param name name of the joint to retrieve
	 * @return the first joint specified by its name found in a body part, null
	 *         if not existing in this model
	 */
	IJoint getJoint(String name);

	/**
	 * @return the torso of this body model
	 */
	IBodyPart getTorso();

	/**
	 * @param name the name of the body part to return
	 * @return the first body part found with passed name, null if not existing
	 */
	IBodyPart getBodyPart(String name);

	/**
	 * @return the center of mass
	 */
	Vector3d getCenterOfMass();

	/**
	 * @param name the name of the hinge joint to change axis speed
	 * @param value the position this joint should reach (in degrees?)
	 */
	void setHingeJointPosition(String name, double value);

	/**
	 * Moves all joints towards their zero position. This method is usually
	 * called to bring the pose as close as possible to the initial pose while
	 * beaming.
	 */
	void performInitialPose();

	/**
	 * Reset all movements (set all joint speeds to 0).
	 */
	void resetAllMovements();

	/**
	 * Adjusts the desired speed of the passed joint to reach current position +
	 * delta
	 * @param name the name of the hinge joint to change axis speed
	 * @param delta the delta angle (deg) to add to the current position
	 */
	void adjustHingeJointPosition(String name, double delta);

	Vector3d[] getEdges(IBodyPart part);

}