/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel;

import java.io.Serializable;

import javax.vecmath.Matrix3d;

import magma.agent.action.IAction;

/**
 * @author Stefan Glaser
 * 
 */
public interface IJoint extends ISensor, Serializable
{
	/**
	 * Called to perform a movement towards the initial position of the joint.
	 */
	public void performInitialPosition();

	/**
	 * Called to reset all currently set movements of the joint and perform no
	 * movement at all (zero axis speed).
	 */
	public void resetMovement();

	/**
	 * Retrieve the rotation matrix, related to the current axis positions of the
	 * joint.
	 * 
	 * @return the rotation matrix of the joint
	 */
	public Matrix3d getRotationMatrix();

	/**
	 * Retrieve the inverse rotation matrix, related to the current axis
	 * positions of the joint.
	 * 
	 * @return the inverse rotation matrix of the joint
	 */
	public Matrix3d getInverseRotationMatrix();

	/**
	 * Informs the action component to create action commands from this joint.
	 * @param action the action component that creates the action protocol
	 */
	public void generateJointAction(IAction action);

	/**
	 * Upates the speed values of this joint by copying them from the passed
	 * joint
	 * @param joint the joint used as source
	 */
	public void updateJointPositionFromJoint(IJoint joint);
}
