/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel.impl;

import javax.vecmath.Vector3d;

import magma.agent.agentmodel.IAccelerometer;
import magma.agent.agentmodel.ISensor;
import magma.agent.perception.IPerception;

/**
 * Implementation of the SimSpark accelerometer sensor
 * 
 * @author Ingo Schindler
 */
class Accelerometer extends Sensor implements IAccelerometer
{
	private static final long serialVersionUID = 1109699252658600557L;

	private Vector3d acceleration;

	/**
	 * Instantiates a new Accelerometer sensor
	 * 
	 * @param name Sensor Name
	 */
	public Accelerometer(String name, String perceptorName)
	{
		super(name, perceptorName);
		acceleration = new Vector3d();
	}

	/**
	 * Copy constructor
	 * @param source the object to copy from
	 */
	private Accelerometer(Accelerometer source)
	{
		super(source.name, source.perceptorName);
		acceleration = new Vector3d(source.acceleration);
	}

	@Override
	public Vector3d getAcceleration()
	{
		return acceleration;
	}

	@Override
	public String getName()
	{
		return name;
	}

	/**
	 * Set 3-dimensional accelerations
	 * 
	 * @param value Accelerations
	 */
	void setAcceleration(Vector3d value)
	{
		value.x = Double.isNaN(value.x) ? 0 : value.x;
		value.y = Double.isNaN(value.y) ? 0 : value.y;
		value.z = Double.isNaN(value.z) ? 0 : value.z;

		acceleration = value;
	}

	/**
	 * Updates this accelerometer from perception
	 * @param perception the result from server message parsing
	 */
	@Override
	public void updateFromPerception(IPerception perception)
	{
		setAcceleration(perception.getAccelerationPerceptor(getPerceptorName())
				.getAcceleration());
	}

	@Override
	public ISensor copy()
	{
		return new Accelerometer(this);
	}
}
