/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel.impl;

import javax.vecmath.Matrix3d;
import javax.vecmath.Vector3d;

import magma.agent.agentmodel.IJoint;
import magma.util.geometry.MatrixUtil;

/**
 * Generic joint representation
 * 
 * @author Stefan Glaser
 */
public abstract class Joint extends Sensor implements IJoint
{
	private static final long serialVersionUID = 8022858047028832383L;

	/** the name of the corresponding effector */
	private final String effectorName;

	Joint(String name, String perceptorName, String effectorName)
	{
		super(name, perceptorName);
		this.effectorName = effectorName;
	}

	/**
	 * Copy constructor
	 * 
	 * @param Source to copy from
	 */
	Joint(Joint source)
	{
		super(source);
		this.effectorName = source.effectorName;
	}

	String getEffectorName()
	{
		return effectorName;
	}

	Matrix3d createRotationMatrix(float angle, Vector3d axis)
	{
		double radAngle = Math.toRadians(angle);

		return MatrixUtil.createRotationMatrix(radAngle * axis.x, radAngle
				* axis.y, radAngle * axis.z);
	}

	Matrix3d createInverseRotationMatrix(float angle, Vector3d axis)
	{
		double radAngle = Math.toRadians(angle);

		return MatrixUtil.createInverseRotationMatrix(radAngle * axis.x, radAngle
				* axis.y, radAngle * axis.z);
	}
}
