/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel.impl;

import java.io.Serializable;

import magma.agent.agentmodel.ISensor;
import magma.agent.perception.IPerception;

/**
 * Base class for all agent sensors
 * 
 * @author Klaus Dorer
 */
public abstract class Sensor implements Serializable, ISensor
{
	private static final long serialVersionUID = 1L;

	/** name of the Sensor */
	final String name;

	/** the name of the corresponding perceptor */
	final String perceptorName;

	/**
	 * Instantiate a new sensor
	 * 
	 * @param name Sensor name
	 */
	Sensor(String name, String perceptorName)
	{
		this.name = name;
		this.perceptorName = perceptorName;
	}

	/**
	 * Copy constructor
	 * @param source to copy from
	 */
	Sensor(Sensor source)
	{
		this.name = source.name;
		this.perceptorName = source.perceptorName;
	}

	/**
	 * Retrieve the sensor name string
	 * 
	 * @return Sensor name
	 */
	@Override
	public String getName()
	{
		return name;
	}

	/**
	 * Get perceptor name
	 * 
	 * @return Perceptor name
	 */
	public String getPerceptorName()
	{
		return perceptorName;
	}

	/**
	 * Updates the joint values in the body model from perception
	 * @param perception the new perception we made
	 */
	@Override
	public abstract void updateFromPerception(IPerception perception);

	@Override
	public boolean equals(Object obj)
	{
		if (!(obj instanceof Sensor)) {
			return false;
		}
		return name.equals(((Sensor) obj).name);
	}

	@Override
	public String toString()
	{
		return name;
	}

	/**
	 * @return a deep copy of this sensor
	 */
	@Override
	public abstract ISensor copy();

	@Override
	public int hashCode()
	{
		return name.hashCode() + super.hashCode();
	}
}
