/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior;

/**
 * Interface to access all behaviors of the agent
 */
public interface IBehavior
{
	/**
	 * Reinitializes the Behavior-StateMachine (if present)
	 */
	public void init();

	/**
	 * Called to perform the behavior
	 */
	public void perform();

	/**
	 * Retrieve the behavior name
	 * 
	 * @return Behavior name
	 */
	public String getName();

	/**
	 * Check if this behavior is finished performing
	 * 
	 * @return True if finished, false if not
	 */
	public boolean isFinished();

	/**
	 * Called when to stop this behavior without caring for stopping it softly
	 */
	public void abort();

	/**
	 * Decide if it is currently possible to switch to another behavior
	 * 
	 * @param newBehavior The behavior one wants to switch to
	 * @return This behavior if it is not yet finished performing, newBehavior
	 *         otherwise
	 */
	public IBehavior switchTo(IBehavior newBehavior);

	/**
	 * @return the intensity with which to perform the behavior.
	 */
	float getIntensity();

	/**
	 * @param intensity the intensity with which to perform the behavior. Values
	 *        are free to use, but are typically in the range of [0..1]
	 */
	void setIntensity(float intensity);

	/**
	 * Retrieve the number of times this behavior has been performe/initialized
	 * 
	 * @return Number of performs
	 */
	int getPerforms();

	/**
	 * This method will only return sensible values for those behaviors that have
	 * implemented a corresponding estimation what successful means.
	 * @return the number of times this behavior has been performed successfully
	 */
	int getSuccessfulPerforms();

	/**
	 * This method will only return sensible values for those behaviors that have
	 * implemented a corresponding estimation what successful means.
	 * @return the number of times this behavior has been performed
	 *         unsuccessfully
	 */
	int getUnsuccessfulPerforms();

	/**
	 * A call might have side effects!!
	 * @return the underlying basic behavior that will be performed.
	 */
	IBehavior getBasicBehavior();
}
