/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior;

import magma.util.geometry.Angle;

import org.apache.commons.math.geometry.Vector3D;

public interface IKick extends IBehavior
{
	/**
	 * @return the kickable rectangle
	 */
	public Vector3D[] getKickableRectangle();

	/**
	 * @return the horizontal direction of the kick (local)
	 */
	public Angle getKickDirection();

	/**
	 * @return the horizontal body direction relative to the ball
	 */
	public Angle getBallFacingDirection();

	/**
	 * @return the maximum distance to the ball in which we hit
	 */
	public double getMaxBallDistance();

	/**
	 * @return the maximum kick distance this kick is able to kick
	 */
	public double getMaxKickDistance();

	/**
	 * @param util
	 */
	public void setUtility(double util);

	/**
	 * @return the utility
	 */
	public double getUtility();
}
