/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior;

public interface IWalk extends IBehavior
{
	/**
	 * Set parameters for Walk. It is possible to combine all different
	 * parameters, e.g. forwards and sidesteps.
	 * 
	 * @param forwards_backwards positive = forwards; negative = backwards (-100
	 *        .. 100)
	 * @param step_left_right positive = right; negative = left (-100 .. 100)
	 * @param turn_left_right positive = right; negative = left (-30 .. 30)
	 */
	public void walk(double forwards_backwards, double step_left_right,
			double turn_left_right);

	/**
	 * Set parameters for Walk. It is possible to combine all different
	 * parameters, e.g. forwards and sidesteps.
	 * 
	 * @param forwards_backwards positive = forwards; negative = backwards (-100
	 *        .. 100)
	 * @param step_left_right positive = right; negative = left (-100 .. 100)
	 * @param turn_left_right positive = right; negative = left (-30 .. 30)
	 */
	public void walk(double forwards_backwards, double step_left_right,
			double turn_left_right, double maxSpeedForward);

	/**
	 * Set parameters to walk in a global direction
	 * 
	 * @param left_right negative = own goal; positive = opponent goal
	 * @param up_down negative = left field side; positive = right field side
	 * @param direction local angle where to go
	 */
	public void globalWalk(double left_right, double up_down, double direction,
			double minSpeedForward, double minSpeedSideward, double maxSpeedForward);
}
