/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.basic;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Serializable;

/**
 * @author Klaus Dorer
 * 
 */
public class BehaviorParameter implements Serializable
{
	/**  */
	private static final long serialVersionUID = 7491159595772287927L;

	/** plain float array to use as chromosom storage */
	private float[] speedFactors;

	/**
	 * Constructor
	 */
	public BehaviorParameter()
	{
		speedFactors = null;
	}

	/**
	 * Retrieve the speed factor list
	 * 
	 * @return the speedFactors
	 */
	public float[] getSpeedFactors()
	{
		return speedFactors;
	}

	/**
	 * Set a list of speed factors
	 * 
	 * @param speedFactors the speedFactors to set
	 */
	public void setSpeedFactors(float[] speedFactors)
	{
		this.speedFactors = speedFactors;
	}

	/**
	 * Writes a function motor file
	 * @param filename the name to use as filename
	 */
	public void writeToFile(String filename)
	{
		PrintWriter out = null;
		try {
			out = new PrintWriter(new FileWriter(filename));

			// write all data for each joint
			for (double value : speedFactors) {
				String line = value + ",";
				out.println(line);
			}

		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (out != null) {
				out.close();
			}
		}
	}
}
