/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.complex;

import java.util.Map;
import java.util.logging.Level;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.geometry.Geometry;
import magma.util.geometry.PositionOrientation;

import org.apache.commons.math.geometry.Vector3D;

/**
 * @author Pret
 * 
 */
public class GoaliePositioning extends ComplexBehavior
{
	/**
	 * Constructor
	 * 
	 * @param globalMap Reference to the GlobalMap
	 * @param agentModel Reference to the AgentModel
	 * @param behaviors List of applicable behaviors
	 */
	public GoaliePositioning(IGlobalMap globalMap, IAgentModel agentModel,
			Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.GOALIE_POSITIONING, globalMap, agentModel,
				behaviors);
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		Vector3D ownGoal = worldModel.getOwnGoalPosition();
		Vector3D ball = worldModel.getBall().getPosition();
		double distance = worldModel.goalHalfWith();

		PositionOrientation result = Geometry.getPointInterpolation(ownGoal,
				ball, distance);

		float fieldHalfLength = worldModel.fieldHalfLength();
		double xOffsetFromGoal = 0.2;

		double newX = (result.getPosition().getX() + fieldHalfLength) * 0.5
				- fieldHalfLength + xOffsetFromGoal;

		Vector3D newPosition = new Vector3D(newX, result.getPosition().getY(), 0);

		RunToPosition runToPosition = (RunToPosition) behaviors
				.get(IBehaviorConstants.RUN_TO_POSITION);

		runToPosition.setPosition(newPosition, (float) result.getOrientationX()
				.radians(), 0, 0, 90);

		logger.log(Level.FINE,
				"goaliePositioning position(x,y) ({0},{1}), angle: {2}",
				new Object[] { newPosition.getX(), newPosition.getY(),
						result.getOrientationX().degrees() });
		return runToPosition;
	}
}
