/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.complex;

import java.awt.geom.Line2D;
import java.util.Map;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.geometry.Angle;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Class in which the Goalie decides in which side to keep
 * @author Rajit Shahi
 * 
 */
public class Keep extends ComplexBehavior
{

	private static final int GOAL_PREDICTION_TIME = 20;

	/** the height of the player */
	private final float playerHeight;

	/**
	 * Constructor
	 * 
	 * @param worldModel - the world model
	 * @param agentModel - the agent model
	 * @param behaviors - a list of behaviors
	 * @param keepLeftBehaviorName - the name of the keep-left behavior
	 * @param keepRightBehaviorName - the name of the keep-right behavior
	 */
	public Keep(IGlobalMap worldModel, IAgentModel agentModel,
			Map<String, IBehavior> behaviors, float playerHeight)
	{
		super(IBehaviorConstants.KEEP, worldModel, agentModel, behaviors);
		this.playerHeight = playerHeight * 1.2f;
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		Vector3D[] futureBallPositions = worldModel.getBall().getFuturePositions(
				GOAL_PREDICTION_TIME);
		Vector3D futureBallPosition = futureBallPositions[futureBallPositions.length - 1];
		Vector3D ballPosition = worldModel.getBall().getPosition();

		Line2D ballLine = new Line2D.Double(futureBallPosition.getX(),
				futureBallPosition.getY(), ballPosition.getX(), ballPosition.getY());

		Vector3D playerPosition = worldModel.getThisPlayer().getPosition();
		Angle playerAngle = worldModel.getThisPlayer().getHorizontalAngle();

		Vector3D left = new Vector3D(playerAngle.add(Math.PI / 2).radians(), 0)
				.normalize().scalarMultiply(playerHeight).add(playerPosition);

		Line2D playerDiameterLeft = new Line2D.Double(playerPosition.getX(),
				playerPosition.getY(), left.getX(), left.getY());

		if (playerDiameterLeft.intersectsLine(ballLine)) {
			return behaviors.get(IBehaviorConstants.KEEP_LEFT);
		}

		return behaviors.get(IBehaviorConstants.KEEP_RIGHT);
	}
}
