/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
/**
 * 
 */
package magma.agent.behavior.complex;

import java.util.Map;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.IWalk;
import magma.agent.behavior.basic.BehaviorParameter;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Specific forward backward walk. Forward with positive intensity, backward
 * with negative.
 * 
 * @author Klaus Dorer
 */
public class WalkForward extends ComplexBehavior
{
	/**
	 * Constructor
	 * 
	 * @param worldModel Reference to the world model
	 * @param agentModel Reference to the agent model
	 * @param params Behavior parameters
	 * @param behaviors List of available behaviors
	 */
	public WalkForward(IGlobalMap worldModel, IAgentModel agentModel,
			BehaviorParameter params, Map<String, IBehavior> behaviors)
	{
		super(IBehaviorConstants.WALKFORWARD, worldModel, agentModel, behaviors,
				behaviors.get(IBehaviorConstants.WALK));
	}

	@Override
	public IBehavior decideNextBasicBehavior()
	{
		IWalk walk = (IWalk) getCurrentBehavior();
		walk.walk(getIntensity() * 100, 0, 0);

		return walk;
	}
}