/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.motor;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.basic.Behavior;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Base class for all behaviors based on static motor movement functions
 */
public abstract class MotorBehavior extends Behavior
{
	/** flag to switch on and off motor file logging */
	protected static final boolean LOG = false;

	/**  */
	boolean finished;

	/**
	 * Default constructor for motor behaviors
	 * 
	 * @param name identifier for this behavior
	 * @param worldModel reference to the world model information
	 * @param agentModel reference to the agent's own information
	 */
	protected MotorBehavior(String name, IGlobalMap worldModel,
			IAgentModel agentModel)
	{
		super(name, worldModel, agentModel);
		this.finished = false;
	}

	/**
	 * Copy constructor
	 * 
	 * @param source Source object to copy state from
	 */
	protected MotorBehavior(MotorBehavior source)
	{
		super(source);
		this.finished = source.finished;
	}

	@Override
	public void init()
	{
		super.init();
		finished = false;
	}

	@Override
	public boolean isFinished()
	{
		return finished;
	}

	/**
	 * @param finished the finished to set
	 */
	public void setFinished(boolean finished)
	{
		this.finished = finished;
	}
}