/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.movement;

import java.util.ArrayList;
import java.util.List;

import magma.agent.agentmodel.IAgentModel;

/**
 * 
 * @author dorer
 */
public class Movement
{
	/** the current phase we are in for performing */
	private int currentPhaseIndex;

	/** the phases of this behavior */
	private List<MovementPhase> phases;

	/** the name of this movement */
	private final String name;

	public Movement(String name)
	{
		this.name = name;
		currentPhaseIndex = 0;
		phases = new ArrayList<MovementPhase>();
	}

	/**
	 * Adds a phase to the list of phases
	 * @param phase the phase to add
	 */
	public void add(MovementPhase phase)
	{
		phases.add(phase);
	}

	public void init()
	{
		currentPhaseIndex = 0;
		for (MovementPhase current : phases) {
			current.init();
		}
	}

	/**
	 * @param agent reference to the agentmodel
	 * @return false if this movement is over
	 */
	public boolean perform(IAgentModel agent)
	{
		if (isFinished()) {
			return false;
		}

		MovementPhase currentPhase = phases.get(currentPhaseIndex);

		// System.out.println("phase: " + currentPhaseIndex + " name: "
		// + currentPhase.getName() + " cycle: "
		// + currentPhase.getCyclesPerformed() + " hip: "
		// + agent.getHJ(INaoConstants.RHipPitch).getAxis() + " knee: "
		// + agent.getHJ(INaoConstants.RKneePitch).getAxis() + " foot: "
		// + agent.getHJ(INaoConstants.RFootPitch).getAxis());

		boolean result = currentPhase.perform(agent);
		if (result == false) {
			currentPhaseIndex++;
			if (isFinished()) {
				return false;
			}
		}
		return true;
	}

	/**
	 * @return true if this movement is over
	 */
	public boolean isFinished()
	{
		return currentPhaseIndex >= phases.size();
	}

	/**
	 * goes to the next phase no matter if this phase is finished
	 * @return
	 */
	public boolean proceed()
	{
		phases.get(currentPhaseIndex).init();
		currentPhaseIndex++;
		if (isFinished()) {
			return false;
		}
		return true;
	}

	public Movement getLeftVersion()
	{
		String newName = name.replace("Right", "Left");
		Movement result = new Movement(newName);
		for (MovementPhase current : phases) {
			MovementPhase newPhase = current.getLeftVersion();
			result.add(newPhase);
		}
		return result;
	}

	@Override
	public String toString()
	{
		return name;
	}
}
