/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model;

import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Interface IReferenceObject<br>
 * Is implemented by the concrete reference object classes.<br>
 * Contains the method getCoordinates().
 * 
 * @author Fox
 * 
 */
public interface IReferenceObject
{
	/**
	 * Function getCoordinates().<br>
	 * Returns the coordinate of the appropriate reference object.
	 * 
	 * @param worldModel
	 * @return coordinates coordinates of the appropriate reference object
	 */
	public Vector3D getCoordinates(IGlobalMap worldModel);

	/**
	 * Function getReferenceObject().<br>
	 * Returns the textual representation of the reference object.<br>
	 * Is overwritten by the concrete child classes.
	 * 
	 * @return reference object textual representation
	 */
	public String getReferenceObject();
}
