/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model;

import java.util.List;

import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Positioning rule interface
 * 
 * @author Denis Zimmermann
 */
public interface IRule
{
	/**
	 * Get the rule name
	 * 
	 * @return Rule name
	 */
	public String getRuleName();

	/**
	 * Set the rule name
	 * 
	 * @param ruleName Rule name
	 */
	public void setRuleName(String ruleName);

	/**
	 * Get the default position
	 * 
	 * @return Default position
	 */
	public List<Double> getDefaultPosition();

	/**
	 * Set the default position
	 * 
	 * @param defaultPosition Default position
	 */
	public void setDefaultPosition(List<Double> defaultPosition);

	/**
	 * Get the action area
	 * 
	 * @return Action area
	 */
	public List<Double> getActionArea();

	/**
	 * Set the action area
	 * 
	 * @param actionArea Action area
	 */
	public void setActionArea(List<Double> actionArea);

	/**
	 * Get the shift
	 * 
	 * @return Shift
	 */
	public List<Double> getShift();

	/**
	 * Set the shift
	 * 
	 * @param shift Shift
	 */
	public void setShift(List<Double> shift);

	public Vector3D positionInArea(Vector3D position);

	public abstract Vector3D getPosition(IGlobalMap worldModel);

	/**
	 * Get the rule type
	 * 
	 * @return Rule type
	 */
	public abstract String getRuleType();

	/**
	 * Get the list of reference objects
	 * 
	 * @return List of reference objects
	 */
	public abstract List<IReferenceObject> getReferenceObjects();

	/**
	 * Set a reference object
	 * 
	 * @param num Object index
	 * @param referenceObject Reference object
	 */
	public abstract void setReferenceObject(int num,
			IReferenceObject referenceObject);
}
