/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model;

import java.util.List;

import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Strategy situation interface
 * 
 * @author Denis Zimmermann
 * 
 */
public interface ISituation
{
	/**
	 * Get Situation name
	 * 
	 * @return Situation name
	 */
	public String getSituationName();

	/**
	 * Get position data
	 * 
	 * @param roleName Role name
	 * @param worldModel World model reference
	 * @return Position
	 */
	public Vector3D getPositionData(String roleName, IGlobalMap worldModel);

	/**
	 * Get a list of available roles
	 * 
	 * @return List of available roles
	 */
	public List<IRole> getRoles();

	/**
	 * Add a role
	 * 
	 * @param role Role
	 * @return True if successful, false if not
	 */
	public boolean addRole(IRole role);

	/**
	 * Remove a role
	 * 
	 * @param role Role
	 * @return True if successful, false if not
	 */
	public boolean removeRole(IRole role);

	public void setRuleName(String ruleName, String roleName);

	public void setRuleType(IRule rule, String roleName);

	public void setShift(List<Double> shift, String roleName);

	public void setDefPos(List<Double> defPos, String roleName);

	public void setActionArea(List<Double> actionArea, String roleName);

	public void setReferenceObject(int num, IReferenceObject referenceObject,
			String roleName);
}
