/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model;

import java.util.List;

/**
 * Strategy developer interface
 * 
 * @author Denis Zimmermann
 */
public interface IStrategyDeveloper
{
	/**
	 * Get strategy name
	 * 
	 * @return Strategy name
	 */
	public String getStrategyName();

	/**
	 * Set strategy name
	 * 
	 * @param strategyName Strategy name
	 */
	public void setStrategyName(String strategyName);

	/**
	 * Get list of situations
	 * 
	 * @return List of situations
	 */
	public List<ISituation> getSituations();

	/**
	 * Add a situation
	 * 
	 * @param situation Situation
	 * @return True if successful, false if not
	 */
	public boolean addSituation(ISituation situation);

	/**
	 * Remove a situation
	 * 
	 * @param situation Situation
	 * @return True if successful, false if not
	 */
	public boolean removeSituation(ISituation situation);

	/**
	 * Add a role to a situation
	 * 
	 * @param situationName Situation name
	 * @param role Role
	 * @return True if successful, false if not
	 */
	public boolean addRole(String situationName, IRole role);

	/**
	 * Remove a role from a situation
	 * 
	 * @param situationName Situation
	 * @param role Role
	 * @return True if successful, false if not
	 */
	public boolean removeRole(String situationName, IRole role);

	public void setRuleName(String ruleName, String situationName,
			String roleName);

	public void setRuleType(IRule rule, String situationName, String roleName);

	public void setShift(List<Double> shift, String situationName,
			String roleName);

	public void setDefPos(List<Double> defPos, String situationName,
			String roleName);

	public void setActionArea(List<Double> actionArea, String situationName,
			String roleName);

	public void setReferenceObject(int num, IReferenceObject referenceObject,
			String situationName, String roleName);
}
