/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model;

import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Interface IStrategyPosition<br>
 * Is implemented by the class Strategy.java.<br>
 * Allows access to getPositionData(), which is implemented by the class
 * Strategy.java.
 * 
 * @author Denis Zimmermann
 */
public interface IStrategyPosition
{
	/**
	 * Function getPositionData()<br>
	 * Returns the position-data dependent on the given role- and situation name.
	 * 
	 * @param roleName name of the role
	 * @param situationName name of the situation
	 * @param worldModel World model reference
	 * @return positionData position-data dependent on the given role- and
	 *         situation-name
	 * @throws Exception
	 */
	public Vector3D getPositionData(String roleName, String situationName,
			IGlobalMap worldModel) throws Exception;
}
