/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import javax.xml.bind.annotation.XmlRootElement;

import magma.agent.behavior.positioning.model.IReferenceObject;
import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Class ReferenceObjectBall<br>
 * Implements the interface IReferenceObject and the method getCoordinates().<br>
 * Represents a ball as a reference object.
 * 
 * @author Denis Zimmermann
 */
@XmlRootElement(name = "ReferenceObjectBall")
public class ReferenceObjectBall implements IReferenceObject
{
	/**
	 * Constructor ReferenceObjectBall
	 */
	public ReferenceObjectBall()
	{
	}

	/**
	 * Function getCoordinates()<br>
	 * Returns the coordinates of the ball.
	 * 
	 * @param worldModel
	 * @return coordinates of the ball
	 */
	@Override
	public Vector3D getCoordinates(IGlobalMap worldModel)
	{
		return worldModel.getBall().getPosition();
	}

	/**
	 * Function getReferenceObject().<br>
	 * Returns the textual representation of the reference object.<br>
	 * 
	 * @return reference object textual representation
	 */
	@Override
	public String getReferenceObject()
	{
		return "Ball";
	}
}
