/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import magma.agent.behavior.positioning.model.IReferenceObject;
import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Class ReferenceObjectLandmark<br>
 * Implements the interface IReferenceObject and the method getCoordinates().<br>
 * Represents a landmark as a reference object.
 * 
 * @author Denis Zimmermann
 */
@XmlRootElement(name = "ReferenceObjectLandmark")
public class ReferenceObjectLandmark implements IReferenceObject
{
	private String landmark; // name of the landmark

	/**
	 * Constructor ReferenceObjectLandmark()<br>
	 * No-Argument-Constructor for testing.<br>
	 * Only use it for testing purposes.
	 */
	public ReferenceObjectLandmark()
	{
	}

	/**
	 * Constructor ReferenceObjectLandmark()
	 * 
	 * @param landmark name of the landmark
	 */
	public ReferenceObjectLandmark(String landmark)
	{
		this.landmark = landmark;
	}

	/**
	 * Function getLankmark()<br>
	 * Returns the name of the landmark.
	 * 
	 * @return landmark Name of the landmark
	 */
	@XmlElement(name = "Landmark")
	String getLandmark()
	{
		return landmark;
	}

	/**
	 * Function setLandmark()<br>
	 * Sets the name of the landmark.
	 * 
	 * @param landmark Name of the landmark
	 */
	public void setLandmark(String landmark)
	{
		this.landmark = landmark;
	}

	/**
	 * Function getCoordinates()<br>
	 * Returns the coordinates of the landmark specified in this object.
	 * 
	 * @param worldModel
	 * @return coordinates of the landmark
	 */
	@Override
	public Vector3D getCoordinates(IGlobalMap worldModel)
	{
		return worldModel.getLandmark(landmark).getPosition();
	}

	/**
	 * Function getReferenceObject().<br>
	 * Returns the textual representation of the reference object.<br>
	 * 
	 * @return reference object textual representation
	 */
	@Override
	public String getReferenceObject()
	{
		return "Landmark_" + getLandmark();
	}
}
