/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import magma.agent.behavior.positioning.model.IReferenceObject;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IPlayer;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Class ReferenceObjectPlayer<br>
 * Implements the interface IReferenceObject and the method getCoordinates().<br>
 * Represents a player as a reference object.
 * 
 * @author Denis Zimmermann
 */
@XmlRootElement(name = "ReferenceObjectPlayer")
public class ReferenceObjectPlayer implements IReferenceObject
{
	private int player; // ID of the player

	/**
	 * Constructor ReferenceObjectPlayer()<br>
	 * No-Argument-Constructor for testing.<br>
	 * Only use it for testing purposes.
	 */
	public ReferenceObjectPlayer()
	{
	}

	/**
	 * Constructor ReferenceObjectPlayer()
	 * 
	 * @param player ID of the player
	 */
	public ReferenceObjectPlayer(int player)
	{
		this.player = player;
	}

	/**
	 * Function getPlayer()<br>
	 * Returns the ID of the player.
	 * 
	 * @return player ID of the player
	 */
	@XmlElement(name = "Player")
	public int getPlayer()
	{
		return player;
	}

	/**
	 * Function setPlayer()<br>
	 * Sets the ID of the player.
	 * 
	 * @param player ID of the player
	 */
	public void setPlayer(int player)
	{
		this.player = player;
	}

	/**
	 * Function getCoordinates()<br>
	 * Returns the coordinates of the player specified in this object.
	 * 
	 * @param worldModel
	 * @return coordinates of the player
	 */
	@Override
	public Vector3D getCoordinates(IGlobalMap worldModel)
	{
		List<IPlayer> playerList = worldModel.getVisiblePlayers();

		for (IPlayer p : playerList) {
			if (p.getID() == this.player) {
				return p.getPosition();
			}
		}

		return null;
	}

	/**
	 * Function getReferenceObject().<br>
	 * Returns the textual representation of the reference object.<br>
	 * 
	 * @return reference object textual representation
	 */
	@Override
	public String getReferenceObject()
	{
		return "Player_" + player;
	}
}
