/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.xml;

import magma.agent.behavior.positioning.model.impl.Strategy;

/**
 * Interface IXMLWrite<br>
 * Extends the interface IXMLRead and is implemented by the class XMLFactory().<br>
 * Enables access to the methods readXML() and createXML(), which are
 * implemented by the class XMLFactory().<br>
 * 
 * @author Denis Zimmermann
 */
public interface IXMLWrite extends IXMLRead
{
	/**
	 * Function createXML()<br>
	 * Creates a XML-file out of the given objects which represent a strategy.
	 * 
	 * @param strategie objects, which represent a strategy
	 * @param dest destination of the XML-file
	 * @return success whether the creation was successful or not
	 */
	public boolean createXML(Strategy strategie, String dest);

	/**
	 * Function deleteXML()<br>
	 * Deletes a XML-file which has the given destination.
	 * 
	 * @param dest destination of the XML-file
	 * @return success whether the deletion was successful or not
	 */
	public boolean deleteXML(String dest);
}
