/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.supportPoint;

import java.util.HashMap;

import magma.util.statemachine.ObjectState;
import magma.util.statemachine.StateFactory;

/**
 * Factory class for behavior (singleton)
 * 
 */
public class BMBStateFactory
		extends
		StateFactory<BMBStateFactory.BehaviorStateEnum, BasicMotorBehavior.BehaviorEvent>
{
	/** constants for the various cleaner states */
	static enum BehaviorStateEnum {
		STARTING, RUNNING
	}

	/**
	 * Called to create the states that are allowed in this state machine
	 */
	@Override
	protected void createStates()
	{
		states = new HashMap<BehaviorStateEnum, ObjectState<BehaviorStateEnum, BasicMotorBehavior.BehaviorEvent>>();
		states.put(BehaviorStateEnum.STARTING, new BMBStateStarting(this));
		states.put(BehaviorStateEnum.RUNNING, new BMBStateRunning(this));
	}

	/**
	 * Called to create the state transitions that are allowed in this state
	 * machine
	 */
	@Override
	protected void createTransitions()
	{
		// transitions from starting state
		ObjectState<BehaviorStateEnum, BasicMotorBehavior.BehaviorEvent> state;
		state = states.get(BehaviorStateEnum.STARTING);
		state.addTransition(new BMBTransitionStartingRunning());
		state.addTransition(new BMBTransitionStartingRunningInit());

		state = states.get(BehaviorStateEnum.RUNNING);
		state.addTransition(new BMBTransitionRunningStarting());
	}

	@Override
	public ObjectState<BehaviorStateEnum, BasicMotorBehavior.BehaviorEvent> getInitialState()
	{
		return getState(BehaviorStateEnum.STARTING);
	}

}
