/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.supportPoint;

import magma.agent.behavior.supportPoint.BMBStateFactory.BehaviorStateEnum;
import magma.agent.behavior.supportPoint.BasicMotorBehavior.BehaviorEvent;
import magma.util.statemachine.IStateFactory;

/**
 * 
 * @author Klaus Dorer
 */
public class BMBStateRunning extends BMBState
{

	/**
	 * Constructor
	 * 
	 * @param factory Behavior factory
	 */
	public BMBStateRunning(
			IStateFactory<BehaviorStateEnum, BehaviorEvent> factory)
	{
		super(factory);
	}

	@Override
	public void perform(BasicMotorBehavior behavior)
	{
		float slowDownFactor = behavior.getSlowDownFactor();
		behavior.performSlowDown();

		float increment = 1.0f / slowDownFactor;
		float currentStep = behavior.getCurrentStep();
		currentStep += increment;
		behavior.setCurrentStep(currentStep);

		if (behavior.willFinish()) {
			behavior.setFinished(true);
			behavior.setCurrentStep(0.0f);
		}
	}

	@Override
	public float calculateSpeed(BasicMotorBehavior behavior, float delta)
	{
		return delta / 2.0f;
	}

	@Override
	public BehaviorStateEnum getStateID()
	{
		return BehaviorStateEnum.RUNNING;
	}
}
