/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.behavior.supportPoint;

import magma.agent.behavior.supportPoint.BMBStateFactory.BehaviorStateEnum;
import magma.agent.behavior.supportPoint.BasicMotorBehavior.BehaviorEvent;
import magma.util.statemachine.IStateFactory;

/**
 * 
 * @author Klaus Dorer
 */
public class BMBStateStarting extends BMBState
{

	/**
	 * Constructor
	 * 
	 * @param factory Behavior factory
	 */
	public BMBStateStarting(
			IStateFactory<BehaviorStateEnum, BehaviorEvent> factory)
	{
		super(factory);
	}

	@Override
	public void perform(BasicMotorBehavior behavior)
	{
		// perform(behavior);
		float slowDownFactor = behavior.getStartSlowDownFactor();
		behavior.performSlowDown();

		float increment = 1.0f / slowDownFactor;
		float currentStep = behavior.getCurrentStep();
		currentStep += increment;
		behavior.setCurrentStep(currentStep);
	}

	@Override
	public float calculateSpeed(BasicMotorBehavior behavior, float delta)
	{
		float speedFactor = behavior.getStartSlowDownFactor()
				* (1.0f - behavior.getCurrentStep());
		float speed = delta / speedFactor;
		if (Math.abs(speed) > Math.abs(delta)) {
			speed = delta;
		}
		return speed;
	}

	@Override
	public BehaviorStateEnum getStateID()
	{
		return BehaviorStateEnum.STARTING;
	}
}
