/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBeliefConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IVisibleObject;
import magma.util.geometry.Geometry;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Checks if the ball is in a "critical" area, indicating that the goalie should
 * run to the ball
 */
public class BallInScorableArea extends Belief
{
	/** the maximum distance we are able to kick the ball */
	private final float kickableDistance;

	/**
	 * Constructor
	 * 
	 * @param agent Reference to the agent model object
	 * @param worldModel Reference to the world model object
	 */
	public BallInScorableArea(IAgentModel agent, IGlobalMap worldModel,
			float kickableDistance)
	{
		super(IBeliefConstants.BALL_IN_SCORABLE_AREA, agent, worldModel);
		this.kickableDistance = kickableDistance;
	}

	@Override
	public float getTruthValue()
	{
		Vector3D otherGoal = worldModel.getOtherGoalPosition();
		IVisibleObject ball = worldModel.getBall();
		double distanceBallGoal = ball.getDistanceToXY(otherGoal);
		return (float) Geometry.getLinearFuzzyValue(worldModel.goalHalfWith(),
				kickableDistance, false, distanceBallGoal);
	}
}
