/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import java.util.logging.Level;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBeliefConstants;
import magma.agent.worldmodel.GameState;
import magma.agent.worldmodel.IGlobalMap;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Checks if the game is running and if not if we should beam
 * @author Klaus Dorer
 */
public class BeamTime extends Belief
{
	/**
	 * Default constructor
	 * 
	 * @param agent Agent model
	 * @param worldModel World model
	 */
	public BeamTime(IAgentModel agent, IGlobalMap worldModel)
	{
		super(IBeliefConstants.BEAM_TIME, agent, worldModel);
	}

	@Override
	public float getTruthValue()
	{
		GameState gameState = worldModel.getGameState();
		if (gameState == GameState.OWN_GOAL
				|| gameState == GameState.OPPONENT_GOAL
				|| gameState == GameState.BEFORE_KICK_OFF) {

			Vector3D position = worldModel.getThisPlayer().getPosition();
			Vector3D homePosition = worldModel.getHomePosition();

			logger.log(Level.FINE,
					"position: ({0}, {1}) home position: ({2}, {3})", new Object[] {
							position.getX(), position.getY(), homePosition.getX(),
							homePosition.getY() });

			double distance = worldModel.getThisPlayer().getDistanceToXY(
					homePosition);
			if (distance > 0.3) {
				return 1.0f;
			}
		}
		return 0.0f;
	}
}
