/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import java.util.logging.Logger;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBelief;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Base class for all Believes
 */
public abstract class Belief implements IBelief
{
	/** handle for logging */
	protected static final Logger logger = Logger.getLogger("");

	/** the name of the believe used to display */
	protected final String name;

	/** link to the agent model */
	protected final IAgentModel agent;

	/** link to the world model */
	protected final IGlobalMap worldModel;

	/**
	 * Constructor
	 * 
	 * @param name Belief name
	 * @param agentModel Reference to the agent model object
	 * @param worldModel Reference to the world model object
	 */
	public Belief(String name, IAgentModel agentModel, IGlobalMap worldModel)
	{
		this.name = name;
		this.agent = agentModel;
		this.worldModel = worldModel;
	}

	@Override
	public abstract float getTruthValue();

	@Override
	public String getName()
	{
		return name;
	}
}
