/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBeliefConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.IThisPlayer;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Checks if we are properly aligned with ball and kick direction
 * 
 * @author Klaus Dorer
 */
public class FacingGoalKickDirection extends FacingAdvantageousKickDirection
{
	/**
	 * Default constructor
	 * 
	 * @param agent Agent model
	 * @param worldModel World model
	 */
	public FacingGoalKickDirection(IAgentModel agent, IGlobalMap worldModel)
	{
		super(IBeliefConstants.FACING_GOAL_KICK_DIRECTION, agent, worldModel);
	}

	@Override
	protected boolean shouldWeKick(double kickToDistance, double ballAngle,
			double goalAngle)
	{
		double ownGoalDistance = worldModel.getThisPlayer().getDistanceToXY(
				worldModel.getOwnGoalPosition());

		if (ownGoalDistance < 3 && Math.abs(ballAngle) < 30
				&& Math.abs(goalAngle) < 80) {
			return true;
		}

		if ((ownGoalDistance < 9 && Math.abs(ballAngle) < 30 && Math
				.abs(goalAngle) < 60)) {
			return true;
		}

		IThisPlayer thisPlayer = worldModel.getThisPlayer();
		IMoveableObject ball = worldModel.getBall();
		Vector3D ballPos = ball.getPosition();
		Vector3D ownPos = thisPlayer.getPosition();
		Vector3D kickTo = worldModel.getOtherGoalPosition();

		// Calculate the position where the straight line through the player and
		// the ball will cross the end of the field

		double m;
		double b;

		// Calculate the straight line to the opponent goal
		double x = kickTo.getX();
		m = (ownPos.getY() - ballPos.getY()) / (ownPos.getX() - ballPos.getX());
		b = ownPos.getY() - m * ballPos.getX();

		// Calculate the Y point of the goal line where the ball will cross the
		// line if we perform a straight kick
		double y = m * x + b;

		if (kickToDistance < 4.5) {
			return y < worldModel.goalHalfWith() && y > -worldModel.goalHalfWith()
					&& Math.abs(ballAngle) < 15;
		}

		return Math.abs(ballAngle) < 30 && Math.abs(goalAngle) < 45;
	}

	@Override
	protected Vector3D getDesiredPosition()
	{
		return worldModel.getOtherGoalPosition();
	}
}
