/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBeliefConstants;
import magma.agent.worldmodel.GameState;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Checks if the game is running already
 * @author Klaus Dorer
 */
public class GameRunning extends Belief
{
	/**
	 * Default constructor
	 * 
	 * @param agent Agent model
	 * @param worldModel World model
	 */
	public GameRunning(IAgentModel agent, IGlobalMap worldModel)
	{
		super(IBeliefConstants.GAME_RUNNING, agent, worldModel);
	}

	@Override
	public float getTruthValue()
	{
		GameState gameState = worldModel.getGameState();
		if (gameState == GameState.PLAY_ON || gameState == GameState.OWN_KICK_OFF
				|| gameState == GameState.OPPONENT_KICK_OFF
				|| gameState == GameState.OWN_GOAL_KICK
				|| gameState == GameState.OPPONENT_GOAL_KICK
				|| gameState == GameState.OWN_FREE_KICK
				|| gameState == GameState.OPPONENT_FREE_KICK
				|| gameState == GameState.OWN_KICK_IN
				|| gameState == GameState.OPPONENT_KICK_IN
				|| gameState == GameState.OWN_CORNER_KICK
				|| gameState == GameState.OPPONENT_CORNER_KICK) {
			return 1.0f;
		}
		return 0.0f;
	}
}
