/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import javax.vecmath.Matrix3d;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBeliefConstants;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Check if the agent lies on its side (which one is not important)
 * 
 * @author Stefan Glaser, Srinivasa Ragavan
 */
public class LayOnSide extends Belief
{
	/**
	 * Constructor
	 * 
	 * @param agent Reference to the agent model object
	 * @param worldModel Reference to the world model object
	 */
	public LayOnSide(IAgentModel agent, IGlobalMap worldModel)
	{
		super(IBeliefConstants.LAY_ON_SIDE, agent, worldModel);
	}

	@Override
	public float getTruthValue()
	{
		Matrix3d orientation = worldModel.getThisPlayer().getOrientation();

		if (orientation.m20 > 0.75 || orientation.m20 < -0.75) {
			return 1.0f;
		}

		return 0.0f;
	}

}
