/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.belief.impl;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.belief.IBeliefConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IPlayer;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Checks if any opponent is close to the ball
 * 
 * @author Klaus Dorer
 */
public class OpponentNearBall extends Belief
{

	/**
	 * Constructor
	 * 
	 * @param agent Reference to the agent model object
	 * @param worldModel Reference to the world model object
	 */
	public OpponentNearBall(IAgentModel agent, IGlobalMap worldModel)
	{
		super(IBeliefConstants.OPPONENT_NEAR_BALL, agent, worldModel);
	}

	@Override
	public float getTruthValue()
	{
		IPlayer opponentAtBall = worldModel.getOpponentAtBall();
		if (opponentAtBall == null) {
			return 0.0f;
		}

		Vector3D ballPosition = worldModel.getBall().getPosition();
		double distance = opponentAtBall.getDistanceToXY(ballPosition);
		if (distance > 1.0) {
			return 0.0f;
		}
		return 1.0f;
	}
}
