/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.decision.simple;

import java.util.Map;

import magma.agent.behavior.IBeam;
import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.belief.IBelief;

/**
 * Decision maker used to trigger training behaviors. Feel free to change it for
 * your own convenience.
 * 
 * @author Klaus Dorer
 */
public class TrainingDecisionMaker extends SoccerDecisionMaker
{
	private boolean haveBeamed;

	/**
	 * Constructor
	 * 
	 * @param believes List of believes
	 * @param behaviors List of applicable behaviors
	 * @param serverVersion Server version number
	 */
	public TrainingDecisionMaker(Map<String, IBelief> believes,
			Map<String, IBehavior> behaviors, int serverVersion)
	{
		super(believes, behaviors, serverVersion);
		haveBeamed = false;
	}

	/**
	 * Called to decide if we should beam us to our home position
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior beamHome()
	{
		if (!haveBeamed) {
			haveBeamed = true;
			IBehavior result = behaviors.get(IBehaviorConstants.BEAM_TO_POSITION);
			((IBeam) result).setPos(-0.17f, -0.05f, 0.0f);
			return result;
		}
		return null;
	}

	/**
	 * Called to decide if we should wait for game start or not. Default
	 * implementation waits.
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior waitForGameStart()
	{
		return null;
	}

	/**
	 * Called to decide if we should kick the ball
	 * @return the behavior to execute, null if this part of decision does not
	 *         trigger a behavior currently
	 */
	@Override
	protected IBehavior doKickBehavior()
	{
		return null;
	}

	/**
	 * Called to decide if movement is necessary
	 * @return walk behavior if no team mate is closer to ball
	 */
	@Override
	protected IBehavior movement()
	{
		// IBehavior behavior = behaviors.get(IBehaviorConstants.WALKFORWARD);
		// behavior.setIntensity(1.0f);
		// IBehavior behavior = behaviors.get(IBehaviorConstants.KEEP);
		IBehavior behavior = behaviors.get(IBehaviorConstants.SHOOT_SIDE_LEFT);
		// IBehavior behavior = behaviors.get("MotionConverterBehavior");
		return behavior;
	}

}
