/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent;

import javax.vecmath.Vector3d;

public interface IHingeJointConfiguration extends IJointConfiguration
{
	/**
	 * Returns a vector, which defines the rotation axis of the joint.
	 * 
	 * @return the rotation axis
	 */
	public Vector3d getJointAxis();

	/**
	 * Returns the minimum possible position-angle of the joint.
	 * 
	 * @return the minimum position angle (deg)
	 */
	public int getMinAngle();

	/**
	 * Returns the maximum possible position-angle of the joint.
	 * 
	 * @return the maximum position angle (deg)
	 */
	public int getMaxAngle();

	/**
	 * Returns the maximum possible speed to the joint.
	 * 
	 * @return the maximum possible speed (deg/cycle)
	 */
	public float getMaxSpeed();
}
