/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent;

import javax.vecmath.Vector3d;

/**
 * Universal joint configuration interface
 * 
 * @author Stefan Glaser
 */
public interface IUniversalJointConfiguration extends IJointConfiguration
{
	/**
	 * Returns a vector, which defines the rotation axis of the joint1.
	 * 
	 * @return the rotation axis of joint1
	 */
	public Vector3d getJoint1Axis();

	/**
	 * Returns a vector, which defines the rotation axis of the joint2.
	 * 
	 * @return the rotation axis of joint2
	 */
	public Vector3d getJoint2Axis();

	/**
	 * Returns the minimum possible position-angle of joint1.
	 * 
	 * @return the minimum position angle of joint1 (deg)
	 */
	public int getJoint1MinAngle();

	/**
	 * Returns the minimum possible position-angle of joint2.
	 * 
	 * @return the minimum position angle of joint2 (deg)
	 */
	public int getJoint2MinAngle();

	/**
	 * Returns the maximum possible position-angle of joint1.
	 * 
	 * @return the maximum position angle of joint1 (deg)
	 */
	public int getJoint1MaxAngle();

	/**
	 * Returns the maximum possible position-angle of joint2.
	 * 
	 * @return the maximum position angle of joint2 (deg)
	 */
	public int getJoint2MaxAngle();

	/**
	 * Returns the maximum possible speed to joint1.
	 * 
	 * @return the maximum possible speed to joint1 (deg/cycle)
	 */
	public float getJoint1MaxSpeed();

	/**
	 * Returns the maximum possible speed to joint2.
	 * 
	 * @return the maximum possible speed to joint2 (deg/cycle)
	 */
	public float getJoint2MaxSpeed();
}
