/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import java.util.List;

import magma.agent.meta.agent.IAgentMetaModel;
import magma.agent.meta.agent.IBodyPartConfiguration;

/**
 * Agent meta model class
 * 
 * @author Stefan Glaser
 */
public class AgentMetaModel implements IAgentMetaModel
{
	protected final String sceneString;

	protected final List<IBodyPartConfiguration> bodyPartConfig;

	protected final String bodyPartContainingCamera;

	/**
	 * Constructor.
	 * 
	 * @param sceneString - the scene string
	 * @param bodyPartConfig - a list of body parts configurations
	 * @param bodyPartContainingCamera - the name of the body part containing the
	 *        camera
	 */
	public AgentMetaModel(String sceneString,
			List<IBodyPartConfiguration> bodyPartConfig,
			String bodyPartContainingCamera)
	{
		this.sceneString = sceneString;
		this.bodyPartConfig = bodyPartConfig;
		this.bodyPartContainingCamera = bodyPartContainingCamera;
	}

	@Override
	public String getSceneString()
	{
		return sceneString;
	}

	@Override
	public List<IBodyPartConfiguration> getBodyPartConfiguration()
	{
		return bodyPartConfig;
	}

	@Override
	public String getNameOfCameraBodyPart()
	{
		return bodyPartContainingCamera;
	}
}
