/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import javax.vecmath.Vector3d;

import magma.agent.meta.agent.IBodyPartConfiguration;
import magma.agent.meta.agent.IJointConfiguration;
import magma.agent.meta.agent.ISensorConfiguration;

public class BodyPartConfiguration implements IBodyPartConfiguration
{
	private final String name;

	private final String parent;

	private final Vector3d translation;

	private final float mass;

	private final Vector3d geometry;

	private final IJointConfiguration jointConfig;

	private final Vector3d jointAnchor;

	private final ISensorConfiguration gyroRateConfig;

	private final ISensorConfiguration accelerometerConfig;

	private final ISensorConfiguration forceResistanceConfig;

	public BodyPartConfiguration(String name, String parent,
			Vector3d translation, float mass, Vector3d geometry,
			IJointConfiguration jointConfig, Vector3d jointAnchor,
			ISensorConfiguration gyroRateConfig,
			ISensorConfiguration accelerometerConfig,
			ISensorConfiguration forceResistanceConfig)
	{
		this.name = name;
		this.parent = parent;
		this.translation = translation;
		this.mass = mass;
		this.geometry = geometry;
		this.jointConfig = jointConfig;
		this.jointAnchor = jointAnchor;
		this.gyroRateConfig = gyroRateConfig;
		this.accelerometerConfig = accelerometerConfig;
		this.forceResistanceConfig = forceResistanceConfig;
	}

	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public String getParent()
	{
		return parent;
	}

	@Override
	public Vector3d getTranslation()
	{
		return translation;
	}

	@Override
	public float getMass()
	{
		return mass;
	}

	@Override
	public Vector3d getGeometry()
	{
		return geometry;
	}

	@Override
	public IJointConfiguration getJointConfiguration()
	{
		return jointConfig;
	}

	@Override
	public Vector3d getJointAnchor()
	{
		return jointAnchor;
	}

	@Override
	public ISensorConfiguration getGyroRateConfiguration()
	{
		return gyroRateConfig;
	}

	@Override
	public ISensorConfiguration getAccelerometerConfiguration()
	{
		return accelerometerConfig;
	}

	@Override
	public ISensorConfiguration getForceResistanceConfiguration()
	{
		return forceResistanceConfig;
	}
}
