/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.agent.impl;

import javax.vecmath.Vector3d;

import magma.agent.meta.agent.IUniversalJointConfiguration;

/**
 * Universal joint configuration
 * 
 * @author Stefan Glaser
 */
public class UniversalJointConfiguration implements
		IUniversalJointConfiguration
{
	private final String name;

	private final String perceptorName;

	private final String effectorName;

	private final Vector3d joint1Axis;

	private final Vector3d joint2Axis;

	private final int joint1MinAngle;

	private final int joint2MinAngle;

	private final int joint1MaxAngle;

	private final int joint2MaxAngle;

	private final float joint1MaxSpeed;

	private final float joint2MaxSpeed;

	public UniversalJointConfiguration(String name, String perceptorName,
			String effectorName, Vector3d joint1Axis, Vector3d joint2Axis,
			int joint1MinAngle, int joint2MinAngle, int joint1MaxAngle,
			int joint2MaxAngle, float joint1MaxSpeed, float joint2MaxSpeed)
	{
		this.name = name;
		this.perceptorName = perceptorName;
		this.effectorName = effectorName;
		this.joint1Axis = joint1Axis;
		this.joint2Axis = joint2Axis;
		this.joint1MinAngle = joint1MinAngle;
		this.joint1MaxAngle = joint1MaxAngle;
		this.joint1MaxSpeed = joint1MaxSpeed;
		this.joint2MinAngle = joint2MinAngle;
		this.joint2MaxAngle = joint2MaxAngle;
		this.joint2MaxSpeed = joint2MaxSpeed;
	}

	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public String getPerceptorName()
	{
		return perceptorName;
	}

	@Override
	public String getEffectorName()
	{
		return effectorName;
	}

	@Override
	public Vector3d getJoint1Axis()
	{
		return joint1Axis;
	}

	@Override
	public Vector3d getJoint2Axis()
	{
		return joint2Axis;
	}

	@Override
	public int getJoint1MinAngle()
	{
		return joint1MinAngle;
	}

	@Override
	public int getJoint2MinAngle()
	{
		return joint2MinAngle;
	}

	@Override
	public int getJoint1MaxAngle()
	{
		return joint1MaxAngle;
	}

	@Override
	public int getJoint2MaxAngle()
	{
		return joint2MaxAngle;
	}

	@Override
	public float getJoint1MaxSpeed()
	{
		return joint1MaxSpeed;
	}

	@Override
	public float getJoint2MaxSpeed()
	{
		return joint2MaxSpeed;
	}
}
