/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.server;

import java.util.Map;

import javax.vecmath.Vector2d;
import javax.vecmath.Vector3d;

public interface IRCServerMetaModel
{

	/**
	 * Returns the version of the meta model (server version)
	 * 
	 * @return server version
	 */
	public int getVersion();

	/**
	 * Returns the decay of the ball
	 * 
	 * @return ball decay
	 */
	public float getBallDecay();

	/**
	 * Returns the dimensions of the soccer field in the form: (length, width)
	 * 
	 * @return the soccer field dimensions (meter)
	 */
	public Vector2d getFieldDimensions();

	/**
	 * Returns the dimensions of the goal in the form: (width, height)
	 * 
	 * @return the goal dimensions (meter)
	 */
	public Vector2d getGoalDimensions();

	/**
	 * Returns the dimensions of the goal area in the form: (width, depth)
	 * 
	 * @return the goal area dimensions (meter)
	 */
	public Vector2d getGoalAreaDimensions();

	/**
	 * Returns the dimensions of the penalty area in the form: (width, depth)
	 * 
	 * @return the penalty area dimensions (meter)
	 */
	public Vector2d getPenaltyAreaDimensions();

	/**
	 * Returns the radii of the middle circle
	 * 
	 * @return the middle circle radii (meter)
	 */
	public float getMiddleCircleRadii();

	/**
	 * Returns a map of landmarks and their known position
	 * 
	 * @return the map of landmarks
	 */
	public Map<String, Vector3d> getLandmarks();

	/**
	 * Returns a map of field lines and their known position
	 * 
	 * @return the map of field lines
	 */
	public Map<String, Vector2d[]> getFieldLines();
}
