/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.server.impl;

import java.util.Map;

import javax.vecmath.Vector2d;
import javax.vecmath.Vector3d;

import magma.agent.meta.server.IRCServerMetaModel;

public class RCServerMetaModel implements IRCServerMetaModel
{
	protected final int version;

	protected final float ballDecay;

	protected final Vector2d fieldDimensions;

	protected final Vector2d goalDimensions;

	protected final Vector2d goalAreaDimensions;

	protected final Vector2d penaltyAreaDimensions;

	protected final float middleCircleRadii;

	protected final Map<String, Vector3d> landmarks;

	protected final Map<String, Vector2d[]> fieldLines;

	public RCServerMetaModel(int version, float ballDecay,
			Vector2d fieldDimensions, Vector2d goalDimensions,
			Vector2d goalAreaDimensions, Vector2d penaltyAreaDimensions,
			float middleCircleRadii, Map<String, Vector3d> landmarks,
			Map<String, Vector2d[]> fieldLines)
	{
		this.version = version;
		this.ballDecay = ballDecay;
		this.fieldDimensions = fieldDimensions;
		this.goalDimensions = goalDimensions;
		this.goalAreaDimensions = goalAreaDimensions;
		this.penaltyAreaDimensions = penaltyAreaDimensions;
		this.middleCircleRadii = middleCircleRadii;
		this.landmarks = landmarks;
		this.fieldLines = fieldLines;
	}

	@Override
	public int getVersion()
	{
		return version;
	}

	@Override
	public float getBallDecay()
	{
		return ballDecay;
	}

	@Override
	public Vector2d getFieldDimensions()
	{
		return fieldDimensions;
	}

	@Override
	public Vector2d getGoalDimensions()
	{
		return goalDimensions;
	}

	@Override
	public Vector2d getGoalAreaDimensions()
	{
		return goalAreaDimensions;
	}

	@Override
	public Vector2d getPenaltyAreaDimensions()
	{
		return penaltyAreaDimensions;
	}

	@Override
	public float getMiddleCircleRadii()
	{
		return middleCircleRadii;
	}

	@Override
	public Map<String, Vector3d> getLandmarks()
	{
		return landmarks;
	}

	@Override
	public Map<String, Vector2d[]> getFieldLines()
	{
		return fieldLines;
	}
}
