/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.meta.server.impl;

import java.util.HashMap;
import java.util.Map;

import javax.vecmath.Vector2d;
import javax.vecmath.Vector3d;

public class RCServerMetaModelV62 extends RCServerMetaModel
{
	private static final float BALL_DECAY = 0.94f;

	private static final float FIELD_HALF_LENGTH = 6.0f;

	private static final float FIELD_HALF_WIDTH = 4.0f;

	private static final float GOAL_HALF_WIDTH = 0.7f;

	private static final float GOAL_HEIGHT = 0.8f;

	/** Make sure to keep this and LANDMARK_POSITIONS in same order */
	private static final String[] LANDMARK_NAMES = { "G1L", "G2L", "G1R", "G2R",
			"F1L", "F2L", "F1R", "F2R" };

	/**
	 * The positions of the visible landmarks in order of LANDMARK_NAMES as used
	 * in version 0.6.2 of the server
	 */
	private static final double[][] LANDMARK_POSITIONS = {
			{ -FIELD_HALF_LENGTH, GOAL_HALF_WIDTH, GOAL_HEIGHT },
			{ -FIELD_HALF_LENGTH, -GOAL_HALF_WIDTH, GOAL_HEIGHT }, // left goal
			// posts
			{ FIELD_HALF_LENGTH, GOAL_HALF_WIDTH, GOAL_HEIGHT },
			{ FIELD_HALF_LENGTH, -GOAL_HALF_WIDTH, GOAL_HEIGHT }, // right goal
			// posts
			{ -FIELD_HALF_LENGTH, FIELD_HALF_WIDTH, 0.0 },
			{ -FIELD_HALF_LENGTH, -FIELD_HALF_WIDTH, 0.0 },
			{ FIELD_HALF_LENGTH, FIELD_HALF_WIDTH, 0.0 },
			{ FIELD_HALF_LENGTH, -FIELD_HALF_WIDTH, 0.0 } };

	public RCServerMetaModelV62()
	{
		super(62, BALL_DECAY, new Vector2d(FIELD_HALF_LENGTH * 2,
				FIELD_HALF_WIDTH * 2), new Vector2d(GOAL_HALF_WIDTH * 2,
				GOAL_HEIGHT), new Vector2d(), new Vector2d(), 1f,
				createLandmarkMap(), null);
	}

	private static Map<String, Vector3d> createLandmarkMap()
	{
		Map<String, Vector3d> landmarks = new HashMap<String, Vector3d>();

		for (int i = 0; i < LANDMARK_NAMES.length; i++) {
			landmarks.put(LANDMARK_NAMES[i], new Vector3d(
					LANDMARK_POSITIONS[i][0], LANDMARK_POSITIONS[i][1],
					LANDMARK_POSITIONS[i][2]));
		}

		return landmarks;
	}
}
