/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.perception;

import java.util.Map;

import org.apache.commons.math.geometry.Vector3D;

/**
 * The Player Position Perceptor represents a single player as reported by the
 * visual sensor sub-system. Provides read-only access only.
 * 
 * @author Simon Raffeiner
 * 
 */
public interface IPlayerPos extends IVisibleObjectPerceptor
{
	/**
	 * Get player id
	 * 
	 * @return Player id
	 */
	int getId();

	/**
	 * Get Team name
	 * 
	 * @return Team name
	 */
	String getTeamname();

	/**
	 * Retrieve a list of all visible body parts
	 * 
	 * @return List of body parts
	 */
	public Map<String, Vector3D> getAllBodyParts();

	/**
	 * Retrieve the 3-dimensional position of a given body part
	 * 
	 * @param partname Body part name
	 * @return Body part position or null if no matching body part was found
	 */
	public Vector3D getBodyPartPosition(String partname);
}