/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.perception.impl;

import javax.vecmath.Vector3d;

import magma.agent.perception.IAccelerometerPerceptor;
import magma.agent.perception.IPerceptor;

/**
 * Acceleration perceptor
 * 
 * @author Simon Raffeiner
 */
class AccelerometerPerceptor extends Perceptor implements
		IAccelerometerPerceptor
{
	private Vector3d vector;

	/**
	 * Default constructor, initializes the accelerometer to (0, 0, 0)
	 * 
	 * @param name Perceptor name
	 */
	public AccelerometerPerceptor(String name)
	{
		this(name, 0.0f, 0.0f, 0.0f);
	}

	/**
	 * Assignment constructor
	 * 
	 * @param name Perceptor name
	 * @param accelX X rotation
	 * @param accelY Y rotation
	 * @param accelZ Z rotation
	 */
	public AccelerometerPerceptor(String name, float accelX, float accelY,
			float accelZ)
	{
		super(name);
		this.vector = new Vector3d(accelX, accelY, accelZ);
	}

	@Override
	public Vector3d getAcceleration()
	{
		return vector;
	}

	@Override
	public void assign(IPerceptor source)
	{
		if (source instanceof AccelerometerPerceptor) {
			AccelerometerPerceptor input = (AccelerometerPerceptor) source;

			vector = input.vector;
		}
	}
}
