/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.perception.impl;

import magma.agent.perception.ILinePerceptor;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Perceptor for line sequence
 * @author dorer
 */
class LinePerceptor extends VisibleObjectPerceptor implements ILinePerceptor
{

	/** End point of the line (polar,perceived) */
	private final Vector3D position2;

	/**
	 * @param name
	 */
	public LinePerceptor(String name, Vector3D pol1, Vector3D pol2)
	{
		super(name, pol1);
		this.position2 = pol2;
	}

	/**
	 * @return the position2
	 */
	@Override
	public Vector3D getPosition2()
	{
		return position2;
	}

	@Override
	public double getDistance2()
	{
		return position2.getNorm();
	}

	@Override
	public double getHorizontalAngle2()
	{
		return position2.getAlpha();
	}

	@Override
	public double getHorizontalAngleDeg2()
	{
		return Math.toDegrees(position2.getAlpha());
	}

	@Override
	public double getLatitudeAngle2()
	{
		return position2.getDelta();
	}

	@Override
	public double getLatitudeAngleDeg2()
	{
		return Math.toDegrees(position2.getDelta());
	}
}
