/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel;

import org.apache.commons.math.geometry.Vector3D;

/**
 * This interface describes a visible field line.
 * 
 * @author Stefan Glaser
 * 
 */
public interface IFieldLine extends IVisibleObject
{
	/**
	 * @return the first local position of the line (relative to the global root
	 *         body system)
	 */
	Vector3D getLocalPosition1();

	/**
	 * @return the second local position of the line (relative to the global root
	 *         body system)
	 */
	Vector3D getLocalPosition2();

	/**
	 * @return the first position of the line in the global coordinate system
	 */
	Vector3D getPosition1();

	/**
	 * @return the second position of the line in the global coordinate system
	 */
	Vector3D getPosition2();
}
