/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel;

import java.util.List;

import magma.util.geometry.Angle;
import magma.util.geometry.PositionOrientation;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Interface to access desired positions
 * @author Klaus Dorer
 */
public interface IPositionManager
{
	/**
	 * @return the desiredPositions
	 */
	public List<PositionOrientation> getDesiredPositions();

	/**
	 * @return the last position orientation in the list
	 */
	public PositionOrientation getFinalPosition();

	/**
	 * Sets the single position this player wants to be
	 * @param desiredPosition coordinates (global) where this player intends to
	 *        be
	 * @param desiredRotation desired angle at the desired position
	 * @param enforceFromOutside true if the position should not be changed
	 */
	public void setDesiredPosition(Vector3D desiredPosition,
			Angle desiredRotation, boolean enforceFromOutside);

	/**
	 * @param posOrientation the position and orientation of desired position
	 * @param enforceFromOutside true if the position should not be changed
	 */
	public void setDesiredPosition(PositionOrientation posOrientation,
			boolean enforceFromOutside);

	/**
	 * adds an intermediate position (with orientation) to the list of positions
	 * @param index the index where to add the new position
	 * @param pos the position orientation to add
	 */
	public void addDesiredPosition(int index, PositionOrientation pos);

	/**
	 * Removes all desired positions from the list
	 */
	public void clear();

}