/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.impl;

import magma.util.geometry.positionFilter.PositionFilter;
import magma.util.geometry.positionFilter.PositionFilterBase;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Represents the ball of the game
 */
public class Ball extends MovableObject
{
	private final float ballDecay;

	/**
	 * Constructor
	 */
	public Ball(float ballDecay)
	{
		super("Ball");
		this.ballDecay = ballDecay;
	}

	private static final long serialVersionUID = 9252371297804616L;

	private final transient PositionFilterBase posFilter = new PositionFilter();

	@Override
	public Vector3D[] getFuturePositions(int aHowMany)
	{
		Vector3D[] futurePositions = new Vector3D[aHowMany];

		Vector3D currentPosition = getPosition();
		Vector3D currentSpeed = getSpeed();

		for (int i = 0; i < aHowMany; i++) {
			currentSpeed = currentSpeed.scalarMultiply(ballDecay);
			currentPosition = currentPosition.add(currentSpeed);
			futurePositions[i] = currentPosition;
		}

		return futurePositions;
	}

	@Override
	public double getPossibleSpeed()
	{
		return 6.0;
	}

	@Override
	public void update(Vector3D localPosition, Vector3D globalPosition,
			float time)
	{
		if (getAge(time) > 5.0f) {
			// If our last update is older than 5 seconds, reset the position
			// filter
			posFilter.reset();
		}
		super.update(localPosition, posFilter.filterPosition(globalPosition),
				time);
	}

	@Override
	public double getCollisionDistance()
	{
		return 0.23;
	}

}