/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.impl;

import magma.agent.worldmodel.IFieldLine;
import magma.agent.worldmodel.localizer.IReferenceLine;

import org.apache.commons.math.geometry.Vector3D;

/**
 * This class respresents a simple field line with a start and end point.
 * @author Stefan Glaser
 * 
 */
public class FieldLine extends VisibleObject implements IFieldLine,
		IReferenceLine
{
	/** */
	private static final long serialVersionUID = 8537923119755820066L;

	private Vector3D localPosition1;

	private Vector3D localPosition2;

	private Vector3D position1;

	private Vector3D position2;

	private final Vector3D knownPosition1;

	private final Vector3D knownPosition2;

	private Vector3D adjustedKnwonPosition1;

	private Vector3D adjustedKnwonPosition2;

	public FieldLine(String name, Vector3D knownPosition1,
			Vector3D knownPosition2)
	{
		super(name);

		this.localPosition1 = new Vector3D();
		this.localPosition2 = new Vector3D();
		this.position1 = new Vector3D();
		this.position2 = new Vector3D();
		this.knownPosition1 = knownPosition1;
		this.knownPosition2 = knownPosition2;
		this.adjustedKnwonPosition1 = knownPosition1;
		this.adjustedKnwonPosition2 = knownPosition2;
	}

	/**
	 * @param pos1 first global position of the line
	 * @param pos2 second global position of the line
	 */
	public void updatePositions(Vector3D pos1, Vector3D pos2, float time)
	{
		Vector3D newPos;
		position1 = pos1;
		position2 = pos2;
		if (pos1 != null && pos2 != null) {
			newPos = pos1.add(pos2).scalarMultiply(.5);
		} else if (pos1 != null) {
			newPos = pos1;
		} else {
			newPos = pos2;
		}

		super.update(localPosition, newPos, time);
	}

	/**
	 * @param pos1 first seen local position of the line
	 * @param pos2 second seen local position of the line
	 */
	@Override
	public void updateLocalPositions(Vector3D pos1, Vector3D pos2)
	{
		localPosition1 = pos1;
		localPosition2 = pos2;
		if (pos1 != null && pos2 != null) {
			localPosition = pos1.add(pos2).scalarMultiply(.5);
		} else if (pos1 != null) {
			localPosition = pos1;
		} else {
			localPosition = pos2;
		}
		setVisible(true);
	}

	@Override
	public void adjustKnownPosition1(Vector3D adjustedKnwonPosition1)
	{
		this.adjustedKnwonPosition1 = adjustedKnwonPosition1;
	}

	@Override
	public void adjustKnownPosition2(Vector3D adjustedKnwonPosition2)
	{
		this.adjustedKnwonPosition2 = adjustedKnwonPosition2;
	}

	@Override
	public Vector3D getPosition1()
	{
		return position1;
	}

	@Override
	public Vector3D getPosition2()
	{
		return position2;
	}

	@Override
	public Vector3D getLocalPosition1()
	{
		return localPosition1;
	}

	@Override
	public Vector3D getLocalPosition2()
	{
		return localPosition2;
	}

	@Override
	public Vector3D getKnownPosition1()
	{
		return knownPosition1;
	}

	@Override
	public Vector3D getKnownPosition2()
	{
		return knownPosition2;
	}

	@Override
	public Vector3D getAdjustedKnownPosition1()
	{
		return adjustedKnwonPosition1;
	}

	@Override
	public Vector3D getAdjustedKnownPosition2()
	{
		return adjustedKnwonPosition2;
	}
}
