/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.localizer;

import java.util.List;

import javax.vecmath.Matrix3d;

import magma.util.geometry.PositionOrientation3D;

/**
 * Implementations are able to calculate the agent's position and orientation
 * from the passed relative information of reference points and lines.<br>
 * Since the observed lines can not be easily assigned to the corresponding
 * known reference lines, one sub-task of the implementations is to try to match
 * these lines and update the corresponding information in the given environment
 * model.
 * 
 * @author Stefan Glaser
 * 
 */
public interface ILocalizer
{
	/**
	 * Determine the absolute position and orientation of the view-port in the 3D
	 * environment.
	 * @param environment a description of the environment, in which the
	 *        localization should take place (set of known reference points and
	 *        lines)
	 * @param lines - A list of currently visible, unlabeled reference lines for
	 *        localization (for line assignment)
	 * @param estimatedOrientation - An approximation of the current global
	 *        orientation (rotation from root body system to global system)
	 * 
	 * @return the localized position and orientation
	 */
	PositionOrientation3D localize(IEnvironmentModel environment,
			List<ILocalizationLine> lines, Matrix3d estimatedOrientation);

	/**
	 * Assign all visible, unlabeled reference lines (<tt>lines</tt>) to the set
	 * of known reference lines defined by the environment model.
	 * @param environment a description of the environment (set of known
	 *        reference points and lines)
	 * @param lines - A list of currently visible, unlabeled reference lines for
	 *        assignment
	 * @param estimatedOrientation - An approximation of the current global
	 *        orientation (rotation from root body system to global system)
	 * @return success
	 */
	boolean assignReferenceLines(IEnvironmentModel environment,
			List<ILocalizationLine> lines, Matrix3d estimatedOrientation);
}
