/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.localizer;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Reference line that can be used for localization.
 * 
 * @author Stefan Glaser
 * 
 */
public interface IReferenceLine
{
	/**
	 * Update the local position of the reference points of the line (relative to
	 * the root body)<br>
	 * Note: By updating a reference line, the line get's visible
	 * @param newLocalPos1 the new local position under which we see the
	 *        reference point 1
	 * @param newLocalPos2 the new local position under which we see the
	 *        reference point 2
	 */
	void updateLocalPositions(Vector3D newLocalPos1, Vector3D newLocalPos2);

	/**
	 * @return the observed position under which we see the first reference point
	 *         of the line (relative to the root body)
	 */
	Vector3D getLocalPosition1();

	/**
	 * @return the observed position under which we see the second reference
	 *         point of the line (relative to the root body)
	 */
	Vector3D getLocalPosition2();

	/**
	 * @return the position at which we know the first reference point is located
	 */
	Vector3D getKnownPosition1();

	/**
	 * @return the position at which we know the second reference point is
	 *         located
	 */
	Vector3D getKnownPosition2();

	/**
	 * This method returns the same as the getKnownPosition1() in case if the
	 * line is fully visible. Is the line not fully visible, this method returns
	 * an adjusted known position according to the length of the seen line.
	 * @return the known position of the second reference point after an possible
	 *         adjustment, if the line is not fully visible
	 */
	Vector3D getAdjustedKnownPosition1();

	/**
	 * This method returns the same as the getKnownPosition2() in case if the
	 * line is fully visible. Is the line not fully visible, this method returns
	 * an adjusted known position according to the length of the seen line.
	 * @return the known position of the second reference point after an possible
	 *         adjustment, if the line is not fully visible
	 */
	Vector3D getAdjustedKnownPosition2();

	/**
	 * Sets the adjusted known position to the first reference point
	 */
	void adjustKnownPosition1(Vector3D adjustedKnwonPosition1);

	/**
	 * Sets the adjusted known position to the second reference point
	 */
	void adjustKnownPosition2(Vector3D adjustedKnwonPosition2);

	/**
	 * Set visibility of reference line (true = assigned; false = not assigned)
	 * 
	 * @param isVisible
	 */
	void setVisible(boolean isVisible);

	/**
	 * @return indicates, if the reference line is currently visible (assigned)
	 */
	boolean isVisible();
}
