/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.localizer.impl;

import magma.agent.worldmodel.localizer.IReferencePoint;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Simple immutable class, combining a local position and a known position. This
 * implementation of a reference point is always visible.
 * 
 * @author Stefan Glaser
 * 
 */
public class ReferencePoint implements IReferencePoint
{
	private final Vector3D localPosition;

	private final Vector3D knownPosition;

	public ReferencePoint(Vector3D localPosition, Vector3D knownPosition)
	{
		this.localPosition = localPosition;
		this.knownPosition = knownPosition;
	}

	@Override
	public Vector3D getLocalPosition()
	{
		return localPosition;
	}

	@Override
	public Vector3D getKnownPosition()
	{
		return knownPosition;
	}

	@Override
	public boolean isVisible()
	{
		return true;
	}

	@Override
	public int compareTo(IReferencePoint o)
	{
		return 0;
	}
}
