/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
/**
 * 
 */
package magma.robots.nao.behavior.dynamic.walk;

import magma.util.function.SplineFunction;

/**
 * Represents a Hip in the robot body
 * 
 * @author Ingo Schindler
 */
public class Hip
{

	private SplineFunction spline;

	private double len;

	/**
	 * Constructor
	 * 
	 * @param p Walking parameters
	 */
	public Hip(WalkBehaviorParameter p)
	{
		setParam(p);
	}

	/**
	 * Set walk behavior parameters
	 * 
	 * @param p Parameters
	 */
	void setParam(WalkBehaviorParameter p)
	{
		double[] yValues = { p.getK() * p.getDs() + p.getX_ed(),
				(p.getK() + 1) * p.getDs() - p.getX_sd(),
				(p.getK()) * p.getDs() + p.getX_ed() };
		double[] xValues = { p.getK() * p.getTc(),
				p.getK() * p.getTc() + p.getTd(), (p.getK() + 1) * p.getTc() };

		spline = new SplineFunction(xValues, yValues);

		len = ((p.getK() + 1) * p.getTc() + p.getTd());
	}

	/**
	 * Calculate the x value based on the current cycle
	 * 
	 * @param t Cycle number (>0)
	 * @return Calculated value
	 */
	public double getXValue(double t)
	{
		if (t < 0)
			throw new IllegalArgumentException("t should be > 0");

		return spline.value(t % len);
	}
}
