/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.behavior.dynamic.walk;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.basic.BehaviorParameter;
import magma.agent.worldmodel.IGlobalMap;

/**
 * Implements a behavior which is able to kick the ball
 */
public class Kick extends Balance
{

	/**
	 * Instantiates and initializes a new Balance behavior object
	 * 
	 * @param worldModel Reference to the world model object
	 * @param agentModel Reference to the agent model object
	 * @param params Behavior parameters
	 */
	public Kick(IGlobalMap worldModel, IAgentModel agentModel,
			BehaviorParameter params)
	{
		super(IBehaviorConstants.SHOOT_SIDE_LEFT, worldModel, agentModel, params);
	}

	@Override
	protected double getSpeed()
	{
		// avoid to kick with side speed
		if (Math.abs(getDirection()) > 5 || Math.abs(getAngle()) > 5) {
			return super.getSpeed();
		}
		return 100;
	}

	// @Override
	// protected double getDirection()
	// {
	// return 0;
	// }

	@Override
	protected void accelerate(double floorX, double floorY)
	{
		// Before kicking we want to decelerate side speed and turning
		setMovement(getSpeed(), 0, 0, false, 100);
		super.accelerate(floorX, floorY);
	}

}
