/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.robots.nao.behavior.movement;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.movement.Movement;
import magma.agent.behavior.movement.MovementBehavior;
import magma.agent.behavior.movement.MovementPhase;
import magma.agent.worldmodel.IGlobalMap;
import magma.robots.nao.INaoConstants;

/**
 * @author Rajit Shahi, Ingo Schindler
 * 
 */
public class KeeperRight extends MovementBehavior
{
	/** movement to jump to the right */
	protected Movement keep;

	/**
	 * Default constructor
	 * 
	 * @param worldModel - the world model
	 * @param agentModel - the agent model
	 */
	public KeeperRight(IGlobalMap worldModel, IAgentModel agentModel)
	{
		this(IBehaviorConstants.KEEP_RIGHT, worldModel, agentModel);
	}

	/**
	 * Default constructor
	 * 
	 * @param name - the name of the behavior
	 * @param worldModel - the world model
	 * @param agentModel - the agent model
	 */
	public KeeperRight(String name, IGlobalMap worldModel, IAgentModel agentModel)
	{
		super(name, worldModel, agentModel);

		keep = new Movement("keepRight");
		keep.add(new MovementPhase("phase1", 200) //
				.add(INaoConstants.LShoulderPitch, 90, 7f) //
				.add(INaoConstants.LShoulderYaw, 0, 7f) //
				.add(INaoConstants.LArmYaw, 0, 7f) //
				.add(INaoConstants.LArmRoll, 0, 7f) //

				.add(INaoConstants.LHipPitch, 0, 7f) //
				.add(INaoConstants.LKneePitch, 0, 7f) //
				.add(INaoConstants.LFootPitch, 0, 7f) //
				.add(INaoConstants.LFootRoll, -20, 7f) //

				.add(INaoConstants.RShoulderPitch, 90, 7f) //
				.add(INaoConstants.RShoulderYaw, 0, 7f) //
				.add(INaoConstants.RArmYaw, 0, 7f) //
				.add(INaoConstants.RArmRoll, 0, 7f) //

				.add(INaoConstants.RHipPitch, 60, 7f) //
				.add(INaoConstants.RKneePitch, -120, 7f) //
				.add(INaoConstants.RFootPitch, 60, 7f) //
				.add(INaoConstants.RFootRoll, -20, 7f) //
		);

		currentMovement = keep;
	}

	@Override
	public void perform()
	{
		if (currentMovement.isFinished()) {
			isFinished = true;
			switchTo(keep);
			return;
		}

		super.perform();
	}

	@Override
	public void init()
	{
		super.init();
		switchTo(keep);
	}
}
