/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.behavior.movement;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.geometry.Angle;
import magma.util.geometry.Geometry;

import org.apache.commons.math.geometry.Vector3D;

/**
 * This behavior kicks somehow to the right with the left foot.
 * 
 * @author Stefan Glaser
 * 
 */
public class SideKickLeft extends SideKickRight
{
	private static final Angle KICK_DIRECTION = Angle.deg(-90);

	private static final Angle BALL_FACING_DIRECTION = Angle.RAD0;

	private static final double BEHIND_BALL_DISTANCE = 0.15;

	private static final double MAX_KICK_DISTANCE = 3.5;

	/** length of the kickable area */
	private static final double MAX_X_KICK = 0.18;

	/** width of the kickable area */
	private static final double MAX_Y_KICK = 0.04;

	private static final Vector3D[] SHOOT_POLY = Geometry
			.getPolygon(new double[][] { { 0, MAX_Y_KICK },
					{ MAX_X_KICK, MAX_Y_KICK }, { MAX_X_KICK, -MAX_Y_KICK },
					{ 0, -MAX_Y_KICK } });

	/**
	 * Default constructor.
	 * 
	 * @param worldModel - the world model
	 * @param agentModel - the agent model
	 */
	public SideKickLeft(IGlobalMap worldModel, IAgentModel agentModel)
	{
		super(IBehaviorConstants.SHOOT_SIDE_LEFT, worldModel, agentModel,
				KICK_DIRECTION, BALL_FACING_DIRECTION, BEHIND_BALL_DISTANCE,
				MAX_KICK_DISTANCE, SHOOT_POLY);

		getOnLeftLeg = getOnLeftLeg.getLeftVersion();
		kickSide = kickSide.getLeftVersion();
	}
}
