/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.robots.nao.meta.agent;

import java.util.ArrayList;
import java.util.List;

import javax.vecmath.Vector3d;

import magma.agent.meta.agent.IBodyPartConfiguration;
import magma.agent.meta.agent.impl.AgentMetaModel;
import magma.agent.meta.agent.impl.BodyPartConfiguration;
import magma.agent.meta.agent.impl.HingeJointConfiguration;
import magma.agent.meta.agent.impl.SensorConfiguration;
import magma.robots.nao.INaoConstants;

public class NaoAgentMetaModel extends AgentMetaModel implements INaoConstants
{
	public NaoAgentMetaModel()
	{
		super(ACTION_SCENE, getNaoBodyPartConfig(), Head);
	}

	private static List<IBodyPartConfiguration> getNaoBodyPartConfig()
	{
		List<IBodyPartConfiguration> configs = new ArrayList<IBodyPartConfiguration>();

		IBodyPartConfiguration currentConfig;

		currentConfig = new BodyPartConfiguration(Torso, null, new Vector3d(0, 0,
				0), 1.2171f, new Vector3d(0.1, 0.1, 0.18), null, new Vector3d(0, 0,
				0), new SensorConfiguration("TorsoGyro", "torso"),
				new SensorConfiguration("TorsoAccel", "torso"), null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(Neck, Torso, new Vector3d(0, 0,
				0.09), 0.05f, new Vector3d(0.03, 0.03, 0.08),
				new HingeJointConfiguration(NeckYaw, "hj1", "he1", new Vector3d(0,
						0, 1), -120, 120, MAX_JOINT_SPEED), new Vector3d(0, 0, 0),
				null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(Head, Neck, new Vector3d(0, 0,
				0.065), 0.35f, new Vector3d(0.13, 0.13, 0.13),
				new HingeJointConfiguration(NeckPitch, "hj2", "he2", new Vector3d(
						1, 0, 0), -45, 45, MAX_JOINT_SPEED), new Vector3d(0, 0,
						-0.005), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RShoulder, Torso, new Vector3d(
				0.098, 0, 0.075), 0.07f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(RShoulderPitch, "raj1", "rae1",
						new Vector3d(1, 0, 0), -120, 120, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RUpperArm, RShoulder,
				new Vector3d(0.01, 0.02, 0), 0.15f, new Vector3d(0.07, 0.08, 0.06),
				new HingeJointConfiguration(RShoulderYaw, "raj2", "rae2",
						new Vector3d(0, 0, 1), -95, 1, MAX_JOINT_SPEED),
				new Vector3d(-0.01, -0.02, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RElbow, RUpperArm,
				new Vector3d(-0.01, 0.07, 0.009), 0.035f, new Vector3d(0.01, 0.01,
						0.01), new HingeJointConfiguration(RArmRoll, "raj3", "rae3",
						new Vector3d(0, 1, 0), -120, 120, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RLowerArm, RElbow,
				new Vector3d(0, 0.05, 0.0), 0.2f, new Vector3d(0.05, 0.11, 0.05),
				new HingeJointConfiguration(RArmYaw, "raj4", "rae4", new Vector3d(
						0, 0, 1), -1, 90, MAX_JOINT_SPEED),
				new Vector3d(0, -0.05, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RHip1, Torso, new Vector3d(
				0.055, -0.01, -0.115), 0.09f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(RHipYawPitch, "rlj1", "rle1",
						new Vector3d(-0.7071, 0, 0.7071), -90, 1, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RHip2, RHip1, new Vector3d(0,
				0, 0), 0.125f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(RHipRoll, "rlj2", "rle2", new Vector3d(
						0, 1, 0), -45, 25, MAX_JOINT_SPEED), new Vector3d(0, 0, 0),
				null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RThight, RHip2, new Vector3d(0,
				0.01, -0.04), 0.275f, new Vector3d(0.07, 0.07, 0.14),
				new HingeJointConfiguration(RHipPitch, "rlj3", "rle3",
						new Vector3d(1, 0, 0), -25, 100, MAX_JOINT_SPEED),
				new Vector3d(0, -0.01, 0.04), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RShank, RThight, new Vector3d(
				0, 0.005, -0.125), 0.225f, new Vector3d(0.08, 0.07, 0.11),
				new HingeJointConfiguration(RKneePitch, "rlj4", "rle4",
						new Vector3d(1, 0, 0), -130, 1, MAX_JOINT_SPEED),
				new Vector3d(0, -0.01, 0.045), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RAnkle, RShank, new Vector3d(0,
				-0.01, -0.055), 0.125f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(RFootPitch, "rlj5", "rle5",
						new Vector3d(1, 0, 0), -45, 75, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(RFoot, RAnkle, new Vector3d(0,
				0.03, -0.035), 0.2f, new Vector3d(0.08, 0.16, 0.03),
				new HingeJointConfiguration(RFootRoll, "rlj6", "rle6",
						new Vector3d(0, 1, 0), -25, 45, MAX_JOINT_SPEED),
				new Vector3d(0, -0.03, 0.035), null, null, new SensorConfiguration(
						"RFootForce", "rf"));
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LShoulder, Torso, new Vector3d(
				-0.098, 0, 0.075), 0.07f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(LShoulderPitch, "laj1", "lae1",
						new Vector3d(1, 0, 0), -120, 120, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LUpperArm, LShoulder,
				new Vector3d(-0.01, 0.02, 0), 0.15f,
				new Vector3d(0.07, 0.08, 0.06), new HingeJointConfiguration(
						LShoulderYaw, "laj2", "lae2", new Vector3d(0, 0, 1), -1, 95,
						MAX_JOINT_SPEED), new Vector3d(0.01, -0.02, 0), null, null,
				null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LElbow, LUpperArm,
				new Vector3d(0.01, 0.07, 0.009), 0.035f, new Vector3d(0.01, 0.01,
						0.01), new HingeJointConfiguration(LArmRoll, "laj3", "lae3",
						new Vector3d(0, 1, 0), -120, 120, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LLowerArm, LElbow,
				new Vector3d(0, 0.05, 0.0), 0.2f, new Vector3d(0.05, 0.11, 0.05),
				new HingeJointConfiguration(LArmYaw, "laj4", "lae4", new Vector3d(
						0, 0, 1), -90, 1, MAX_JOINT_SPEED),
				new Vector3d(0, -0.05, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LHip1, Torso, new Vector3d(
				-0.055, -0.01, -0.115), 0.09f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(LHipYawPitch, "llj1", "lle1",
						new Vector3d(-0.7071, 0, -0.7071), -90, 1, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LHip2, LHip1, new Vector3d(0,
				0, 0), 0.125f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(LHipRoll, "llj2", "lle2", new Vector3d(
						0, 1, 0), -25, 45, MAX_JOINT_SPEED), new Vector3d(0, 0, 0),
				null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LThight, LHip2, new Vector3d(0,
				0.01, -0.04), 0.275f, new Vector3d(0.07, 0.07, 0.14),
				new HingeJointConfiguration(LHipPitch, "llj3", "lle3",
						new Vector3d(1, 0, 0), -25, 100, MAX_JOINT_SPEED),
				new Vector3d(0, -0.01, 0.04), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LShank, LThight, new Vector3d(
				0, 0.005, -0.125), 0.225f, new Vector3d(0.08, 0.07, 0.11),
				new HingeJointConfiguration(LKneePitch, "llj4", "lle4",
						new Vector3d(1, 0, 0), -130, 1, MAX_JOINT_SPEED),
				new Vector3d(0, -0.01, 0.045), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LAnkle, LShank, new Vector3d(0,
				-0.01, -0.055), 0.125f, new Vector3d(0.01, 0.01, 0.01),
				new HingeJointConfiguration(LFootPitch, "llj5", "lle5",
						new Vector3d(1, 0, 0), -45, 75, MAX_JOINT_SPEED),
				new Vector3d(0, 0, 0), null, null, null);
		configs.add(currentConfig);

		currentConfig = new BodyPartConfiguration(LFoot, LAnkle, new Vector3d(0,
				0.03, -0.035), 0.2f, new Vector3d(0.08, 0.16, 0.03),
				new HingeJointConfiguration(LFootRoll, "llj6", "lle6",
						new Vector3d(0, 1, 0), -45, 25, MAX_JOINT_SPEED),
				new Vector3d(0, -0.03, 0.035), null, null, new SensorConfiguration(
						"LFootForce", "lf"));
		configs.add(currentConfig);

		return configs;
	}
}
