/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.util;

import org.apache.commons.math.geometry.Vector3D;

/**
 * En- and Decoder of messages
 * @author dorer
 */
public class SayCoder
{
	/**
	 * @param id a number (0..25) to encode
	 * @return a String representation of the number
	 */
	public static String encodeID(int id)
	{
		return "" + (char) ('a' + id);
	}

	/**
	 * @param text the text to decode
	 * @return a number (0..25) decoded from text
	 */
	public static int decodeID(String text)
	{
		if (text.length() != 1) {
			return -1;
		}
		return text.charAt(0) - 'a';
	}

	/**
	 * Encodes the passed vectors x and y coordinate into a String
	 * @return the passed vectors x and y coordinate encoded into a String
	 */
	public static String encodePosition(Vector3D position)
	{
		int xShort = (int) ((position.getX() + 20) * 10);
		int yShort = (int) ((position.getY() + 20) * 10);
		return String.format("%03d%03d", xShort, yShort);
	}

	/**
	 * Converts a position string into a Vector3D
	 * @param text the text to convert as 6 digit String (see encodePosition)
	 * @return the decoded position, null if the text did not allow to decode
	 */
	public static Vector3D decodePosition(String text)
	{
		if (text.length() != getPositionLength()) {
			return null;
		}
		if (text.equals(encodeInvalidPosition())) {
			return null;
		}
		try {
			int x = new Integer(text.substring(0, 3));
			int y = new Integer(text.substring(3, 6));

			float xlong = (x / 10.0f) - 20;
			float ylong = (y / 10.0f) - 20;
			return new Vector3D(xlong, ylong, 0);

		} catch (Exception e) {
			return null;
		}
	}

	/**
	 * @return the encoding of an invalid position
	 */
	public static String encodeInvalidPosition()
	{
		return "000000";
	}

	/**
	 * @return the string length of a position encoding
	 */
	public static int getPositionLength()
	{
		return 6;
	}

	/**
	 * @param name the name to encode
	 * @return the encoded version of the passed name
	 */
	public static String encodeName(String name)
	{
		return encodeID(Math.abs(name.hashCode()) % 20);
	}
}
