/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.util.command;

/**
 * Represents a command that can be done and undone
 * 
 * @author Klaus Dorer
 */
public interface ICommand
{
	/**
	 * @return the name of this command
	 */
	String getName();

	/**
	 * Performs this command
	 * @return true if the command was performed successfully
	 */
	boolean perform();

	/**
	 * Called to undo the changes of the command that have been done through
	 * perform
	 */
	void undo();

	/**
	 * Checks if this command is mergeable (in the undo list) with the passed
	 * command
	 * @param newCommand the command to check mergability
	 * @return true if this command can be merged with the passed
	 */
	boolean isMergeable(ICommand newCommand);

	/**
	 * Merges this command with the passed command so that this command
	 * represents both
	 * @param newCommand the command to merge into this
	 */
	void merge(ICommand newCommand);
}
