/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry;

import javax.vecmath.Matrix4d;
import javax.vecmath.Vector3d;

/**
 * Denavit/Hartenberg Transformation implementation
 * 
 * @author Ingo Schindler
 */
class DenavitHartenberg
{
	/**
	 * Transform a 3-dimensional vector with the given parameters using the
	 * Denavit/Hartenberg transformation
	 * 
	 * @param origin Origin
	 * @param p parameters
	 * @return Transformed vector
	 */
	public static Vector3d transform(Vector3d origin,
			DenavitHartenbergParameters p)
	{

		Matrix4d transformation;

		Matrix4d rotationX = new Matrix4d();
		rotationX.rotX(p.getAlpha());

		Matrix4d rotationY = new Matrix4d();
		rotationY.rotY(p.getBeta());

		Matrix4d rotationZ = new Matrix4d();
		rotationZ.rotZ(p.getTheta());

		Matrix4d translation = new Matrix4d();
		translation.rotZ(0);
		translation.setTranslation(p.getDistance());

		transformation = rotationX;

		transformation.mul(translation);

		transformation.mul(rotationZ);

		return MatrixUtil.mulMatrixVector(transformation, origin);
	}
}
