/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry;

import javax.vecmath.Matrix3d;
import javax.vecmath.Vector3d;

public class InverseKinematics
{
	public static double[] jacobianTranspose(Vector3d targetPos,
			Vector3d currentPos, double[][] jacobian, double deLimit)
	{
		double[] dTheta = new double[jacobian[0].length];
		Vector3d de = new Vector3d(targetPos);

		// de = end_goal - e;
		de.sub(currentPos);

		if (de.length() > deLimit) {
			de.normalize();
			de.scale(deLimit);
		}

		// % Compute alpha constant as quotient of 2 inner products as suggested
		// % by Buss & Kim, to minimze de after caller updates theta
		// JJTde = J*J'*de;
		Matrix3d JJ_T = getJJ_T(jacobian);
		Vector3d JJ_Tde = new Vector3d(de);
		JJ_T.transform(JJ_Tde);

		// alpha = (de'*JJTde)/(JJTde'*JJTde);
		double alpha = de.dot(JJ_Tde) / JJ_Tde.dot(JJ_Tde);

		// dTheta = transpose(alpha * J' * de);
		for (int i = 0; i < jacobian[0].length; i++) {
			dTheta[i] = alpha
					* (jacobian[0][i] * de.x + jacobian[1][i] * de.y + jacobian[2][i]
							* de.z);
		}

		return dTheta;
	}

	private static Matrix3d getJJ_T(double[][] j)
	{
		Matrix3d res = new Matrix3d();

		res.m00 = getMXXofMM_T(j, 0, 0);
		res.m01 = getMXXofMM_T(j, 0, 1);
		res.m02 = getMXXofMM_T(j, 0, 2);
		res.m10 = getMXXofMM_T(j, 1, 0);
		res.m11 = getMXXofMM_T(j, 1, 1);
		res.m12 = getMXXofMM_T(j, 1, 2);
		res.m20 = getMXXofMM_T(j, 2, 0);
		res.m21 = getMXXofMM_T(j, 2, 1);
		res.m22 = getMXXofMM_T(j, 2, 2);

		return res;
	}

	private static double getMXXofMM_T(double[][] m, int row, int col)
	{
		double res = 0;

		for (int i = 0; i < m[0].length; i++) {
			res += m[row][i] * m[col][i];
		}

		return res;
	}
}
