/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry;

import java.io.Serializable;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Stores position and orientation
 */
public class PositionOrientation implements Serializable
{
	/** */
	private static final long serialVersionUID = 3511039404384477686L;

	private Vector3D position;

	/** horizontal angle in radians */
	private Angle orientationX;

	/**
	 * @param position position
	 * @param orientationX horizontal angle (rad)
	 */
	public PositionOrientation(Vector3D position, Angle orientationX)
	{
		this.position = position;
		this.orientationX = orientationX;
	}

	/**
	 * @return the position
	 */
	public Vector3D getPosition()
	{
		return position;
	}

	/**
	 * @param position the position to set
	 */
	public void setPosition(Vector3D position)
	{
		this.position = position;
	}

	/**
	 * @return the horizontal angle (rad)
	 */
	public Angle getOrientationX()
	{
		return orientationX;
	}

	/**
	 * @param orientationX the horizontal angle (rad) to set
	 */
	public void setOrientationX(Angle orientationX)
	{
		this.orientationX = orientationX;
	}

	/**
	 * Calculate the average of a list of PositionOrientations
	 * 
	 * @param input Array of input values
	 * @return Calculated average
	 */
	public static PositionOrientation average(PositionOrientation[] input)
	{
		// float angle = averageAngle(angles);
		double x = 0.0;
		double y = 0.0;
		double z = 0.0;

		// average position
		for (PositionOrientation value : input) {
			x += value.getPosition().getX();
			y += value.getPosition().getY();
			z += value.getPosition().getZ();
		}
		if (input.length > 1) {
			x /= input.length;
			y /= input.length;
			z /= input.length;
		}
		Vector3D pos = new Vector3D(x, y, z);

		// average angles
		Angle[] angles = new Angle[input.length];
		for (int i = 0; i < input.length; i++) {
			angles[i] = input[i].getOrientationX();
		}
		Angle angle = Angle.average(angles);
		return new PositionOrientation(pos, angle);
	}

	@Override
	public String toString()
	{
		StringBuilder result = new StringBuilder();
		result.append("(").append(position.getX()).append(",");
		result.append(position.getY()).append(",");
		result.append(position.getZ()).append("/");
		result.append(orientationX.degrees()).append(")");
		return result.toString();
	}

}
