/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry;

import java.io.Serializable;

import javax.vecmath.Matrix3d;

import org.apache.commons.math.geometry.Vector3D;

/**
 * Stores position and orientation in 3D
 * 
 * @author Klaus Dorer
 */
public class PositionOrientation3D implements Serializable
{
	/** */
	private static final long serialVersionUID = 1969426925498896576L;

	private Vector3D position;

	private Matrix3d orientation;

	/**
	 * Instantiate a new PositionOrientation3D object and initialize position and
	 * orientation
	 * 
	 * @param position Position
	 * @param orientation Orientation
	 */
	public PositionOrientation3D(Vector3D position, Matrix3d orientation)
	{
		this.position = position;
		this.orientation = orientation;
	}

	/**
	 * Retrieve the position
	 * 
	 * @return the position
	 */
	public Vector3D getPosition()
	{
		return position;
	}

	/**
	 * Set the position
	 * 
	 * @param position the position to set
	 */
	public void setPosition(Vector3D position)
	{
		this.position = position;
	}

	/**
	 * Retrieve the orentiation
	 * 
	 * @return Orientation
	 */
	public Matrix3d getOrientation()
	{
		return orientation;
	}

	/**
	 * Set orientation
	 * 
	 * @param orientation New orientation
	 */
	public void setOrientation(Matrix3d orientation)
	{
		this.orientation = orientation;
	}
}
