/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.statemachine;

import java.util.Map;

/**
 * Generic factory class for state machine pattern
 * 
 * @author Klaus Dorer
 * @param <K> the enum used to identify states
 * @param <E> the enum used to identify events
 */
public abstract class StateFactory<K, E> implements IStateFactory<K, E>
{
	/** map containing all states */
	protected Map<K, ObjectState<K, E>> states;

	/**
	 * Default constructor creating the states and transitions of the state
	 * machine
	 */
	protected StateFactory()
	{
		createStates();
		createTransitions();
	}

	/**
	 * Called to create the states that are allowed in this state machine
	 */
	protected abstract void createStates();

	/**
	 * Called to create the state transitions that are allowed in this state
	 * machine
	 */
	protected abstract void createTransitions();

	@Override
	public ObjectState<K, E> getState(K state)
	{
		return states.get(state);
	}
}
