/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.agentmodel.impl;

import static org.junit.Assert.assertEquals;

import javax.vecmath.Vector3d;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.meta.agent.impl.HingeJointConfiguration;
import magma.robots.nao.meta.agent.NaoAgentMetaModel;
import magma.util.SerializationUtil;

import org.junit.Before;
import org.junit.Test;

/**
 * Tests for Serialization of agent model
 * @author Klaus Dorer
 */
public class SerializationTest
{
	private HingeJoint testee1;

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception
	{
		testee1 = new HingeJoint(new HingeJointConfiguration("test", "test",
				"test", new Vector3d(1, 0, 0), -120, 120, 7));
		testee1.updateAxisPosition(60);
		testee1.updateAxisPosition(50);
	}

	@Test
	public void testHingeJointSerialization() throws Exception
	{
		HingeJoint result = (HingeJoint) SerializationUtil
				.doubleSerialize(testee1);
		assertEquals(testee1, result);
	}

	@Test
	public void testAgentModelSerialization() throws Exception
	{
		IAgentModel model = new AgentModel(null, new NaoAgentMetaModel());
		IAgentModel result = (IAgentModel) SerializationUtil
				.doubleSerialize(model);
		assertEquals(result, model);
	}
}
