/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.complex;

import static org.easymock.EasyMock.expect;
import static org.easymock.classextension.EasyMock.createMock;
import static org.easymock.classextension.EasyMock.replay;
import static org.junit.Assert.assertEquals;

import java.util.HashMap;
import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.impl.ThisPlayer;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Test;

/**
 * Test for {@link magma.agent.behavior.complex.GetInScorePosition}
 * 
 * @author sturmflut
 */
public class GetInScorePositionTest
{
	private GetInScorePosition testee;

	private IGlobalMap worldModelMock;

	private IMoveableObject ballMock;

	private ThisPlayer thisPlayer;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		worldModelMock = createMock(IGlobalMap.class);
		ballMock = createMock(IMoveableObject.class);
		thisPlayer = new ThisPlayer("test", 1);
		Map<String, IBehavior> behaviors = new HashMap<String, IBehavior>();
		testee = new GetInScorePosition(worldModelMock, null, behaviors);
	}

	@Test
	public void testPerform()
	{
		thisPlayer.setPosition(new Vector3D(0, 0, 0));
		expect(worldModelMock.getBall()).andReturn(ballMock);
		expect(worldModelMock.getThisPlayer()).andReturn(thisPlayer);
		Vector3D otherGoalPosition = new Vector3D(6.0, 0.0, 0.0);
		expect(worldModelMock.getOtherGoalPosition())
				.andReturn(otherGoalPosition);
		expect(worldModelMock.fieldHalfWith()).andStubReturn(6f);
		expect(worldModelMock.goalHalfWith()).andStubReturn(1.05f);
		double ballX = 2.0;
		Vector3D ballPosition = new Vector3D(ballX, 0.0, 0.0);
		expect(ballMock.getPosition()).andReturn(ballPosition);
		expect(ballMock.getDistanceToXY(otherGoalPosition)).andReturn(4.0);
		// this is the expected position
		replay(worldModelMock, ballMock);

		double[] result = testee.getPosition();

		assertEquals(ballX - GetInScorePosition.BEHIND_BALL_DISTANCE, result[0],
				0.001);
		assertEquals(0.0, result[1], 0.001);
		assertEquals(0.0, result[2], 0.001);

	}

}
