/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
/**
 * 
 */
package magma.agent.behavior.complex;

import static org.easymock.EasyMock.expect;
import static org.easymock.classextension.EasyMock.createMock;
import static org.easymock.classextension.EasyMock.replay;
import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.IPlayer;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;

/**
 * @author Denis Zimmermann
 */
public class PassivePositioningTest
{
	private PassivePositioning testee; // testee

	private IGlobalMap worldModelMock; // Mock for the worldModel

	private IMoveableObject ballMock; // Mock for the ball

	private IPlayer ownPlayerMock; // Mock for a player of the own team

	/**
	 * setUp function for every test
	 */
	@Before
	public void setUp()
	{
		Map<String, IBehavior> behaviors = new HashMap<String, IBehavior>();
		worldModelMock = createMock(IGlobalMap.class);
		ballMock = createMock(IMoveableObject.class);
		ownPlayerMock = createMock(IPlayer.class);
		testee = new PassivePositioning(worldModelMock, null, behaviors);
	}

	/**
	 * Test for the determineSituation function
	 */
	@Test
	@Ignore
	public void testDetermineSituationCornerKickLeftAboveOwn()
	{
		Vector3D ballPosition = new Vector3D(-3.0, 5.0, 0.0);

		List<IPlayer> playerList = new ArrayList<IPlayer>();
		playerList.add(ownPlayerMock);
		expect(ownPlayerMock.isOwnTeam()).andReturn(true);

		// expect(worldModelMock.getPlaymode()).andReturn(PlayMode.CORNER_KICK_LEFT);
		expect(worldModelMock.getBall()).andReturn(ballMock);
		expect(ballMock.getPosition()).andReturn(ballPosition);
		expect(worldModelMock.getPlayersAtBallList()).andReturn(playerList);

		replay(worldModelMock, ballMock, ownPlayerMock);

		String situation = testee.determineSituation();

		assertEquals(situation, "Corner_kick_left_above_own");
	}

	/**
	 * Test for the determineSituation function
	 */
	@Test
	@Ignore
	public void testDetermineSituationKickInRightBelowOpponent()
	{
		Vector3D ballPosition = new Vector3D(-3.0, -5.0, 0.0);

		List<IPlayer> playerList = new ArrayList<IPlayer>();
		playerList.add(ownPlayerMock);
		expect(ownPlayerMock.isOwnTeam()).andReturn(false);

		// expect(worldModelMock.getPlaymode()).andReturn(PlayMode.KICK_IN_RIGHT);
		expect(worldModelMock.getBall()).andReturn(ballMock);
		expect(ballMock.getPosition()).andReturn(ballPosition);
		expect(worldModelMock.getPlayersAtBallList()).andReturn(playerList);

		replay(worldModelMock, ballMock, ownPlayerMock);

		String situation = testee.determineSituation();

		assertEquals(situation, "Kick_in_right_below_opponent");
	}

	/**
	 * Test for the determineSituation function
	 */
	@Test
	@Ignore
	public void testDetermineSituationFreeKickLeftOpponent()
	{
		Vector3D ballPosition = new Vector3D(-3.0, 2.0, 0.0);

		List<IPlayer> playerList = new ArrayList<IPlayer>();
		playerList.add(ownPlayerMock);
		expect(ownPlayerMock.isOwnTeam()).andReturn(false);

		// expect(worldModelMock.getPlaymode()).andReturn(PlayMode.FREE_KICK_LEFT);
		expect(worldModelMock.getBall()).andReturn(ballMock);
		expect(ballMock.getPosition()).andReturn(ballPosition);
		expect(worldModelMock.getPlayersAtBallList()).andReturn(playerList);

		replay(worldModelMock, ballMock, ownPlayerMock);

		String situation = testee.determineSituation();

		assertEquals(situation, "Free_kick_left_opponent");
	}
}
