/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.complex;

import static org.easymock.EasyMock.anyObject;
import static org.easymock.EasyMock.expect;
import static org.easymock.classextension.EasyMock.replay;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertSame;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import magma.agent.behavior.IBehavior;
import magma.agent.behavior.IBehaviorConstants;
import magma.agent.behavior.basic.NoneBehavior;
import magma.agent.worldmodel.IPlayer;
import magma.agent.worldmodel.IVisibleObject;
import magma.agent.worldmodel.impl.WorldModelBaseTest;
import magma.util.geometry.Angle;
import magma.util.geometry.PositionOrientation;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Test;

public class RunToPositionTest extends WorldModelBaseTest
{
	private RunToPosition testee;

	private PositionOrientation goalPosOr;

	private List<IVisibleObject> obstacles;

	private Vector3D goalPos;

	private ArrayList<IPlayer> teammatesAtBall;

	@Override
	@Before
	public void setUp()
	{
		super.setUp();
		goalPos = new Vector3D(4, 0, 0);
		goalPosOr = new PositionOrientation(goalPos, Angle.deg(0));
		Map<String, IBehavior> behaviors = new HashMap<String, IBehavior>();
		behaviors.put(IBehaviorConstants.NONE, new NoneBehavior());
		obstacles = new ArrayList<IVisibleObject>();
		expect(playerMock1.getName()).andStubReturn("player1");
		expect(worldModelMock.getObstacles()).andStubReturn(obstacles);
		teammatesAtBall = new ArrayList<IPlayer>();
		expect(worldModelMock.getTeammatesAtBall())
				.andStubReturn(teammatesAtBall);

		testee = new RunToPosition(worldModelMock, null, behaviors);
	}

	// @Test
	// public void testPerformFar()
	// {
	// Walk behavior = new Walk(null, null, new WalkBehaviorParameter(), null,
	// null);
	// // IBehavior behavior = new NoneBehavior();
	// runTest(behavior, Angle.RAD0,
	// RunToPosition.FASTEST_TO_RUN_DISTANCE + 0.1, Angle.RAD0, 0.0f,
	// 0.0f, true, 0.0f);
	// assertEquals(100.0, behavior.getDesiredSpeed(), 0.0001);
	// }

	// @Test
	// public void testPerformThere()
	// {
	// Balance behavior = new Balance(IBehavior.BALANCE, null, null,
	// new WalkBehaviorParameter(), null, null);
	// runTest(behavior, Angle.RAD0, RunToPosition.DISTANCE_PRECISION - 0.1,
	// Angle.RAD0, 0.0f, 0.0f, true, 0.0f);
	// assertEquals(0.0, behavior.getDesiredSpeed(), 0.0001);
	// }

	// @Test
	// public void testPerformThereNoneHeadingRight()
	// {
	// Balance behavior = new Balance(IBehavior.BALANCE, null, null,
	// new WalkBehaviorParameter(), null, null);
	// runTest(behavior, Angle.RAD90, RunToPosition.DISTANCE_PRECISION - 0.1,
	// Angle.deg(90), 0.0f, 0.0f, true, 0.0f);
	// assertEquals(0.0, behavior.getDesiredSpeed(), 0.0001);
	// }

	// @Test
	// public void testPerformCloseStepLeft()
	// {
	// IBehavior behavior = new Walk(null, null, new WalkBehaviorParameter(),
	// null);
	// runTest(behavior, Angle.deg(90),
	// RunToPosition.FASTEST_TO_RUN_DISTANCE - 0.1, Angle.RAD0, 1.0f,
	// 0.5f, true, 0.0f);
	// }
	//
	// @Test
	// public void testPerformCloseStepRight()
	// {
	// IBehavior behavior = new Walk(null, null, new WalkBehaviorParameter(),
	// null);
	// runTest(behavior, Angle.deg(-90),
	// RunToPosition.FASTEST_TO_RUN_DISTANCE - 0.1, Angle.RAD0, 1.0f,
	// 0.5f, false, 0.0f);
	// }

	// @Test
	// public void testPerformCloseBackstep()
	// {
	// Balance behavior = new Balance(null, null, new WalkBehaviorParameter(),
	// behaviors, null);
	// runTest(behavior, Angle.deg(180),
	// RunToPosition.FASTEST_TO_RUN_DISTANCE - 0.1, Angle.RAD0, 1.0f,
	// 1.5f, true, 0.5f);
	// assertEquals(-80, behavior.getDesiredSpeed(), 0.0001);
	// }
	//
	// private void runTest(IBehavior behavior, Angle nowRotation,
	// double desiredDistance, Angle desiredRotation, float turnAndRunTime,
	// float sideStepTime, boolean isLeft, float backStepTime)
	// {
	// behaviors.put(behavior.getName(), behavior);
	// prepareThisPlayerMock(nowRotation, desiredDistance, desiredRotation,
	// turnAndRunTime, sideStepTime, isLeft, backStepTime);
	// replay(worldModelMock, thisPlayerMock);
	// IBehavior result = testee.decideNextBasicBehavior();
	// assertEquals(behavior.getName(), result.getName());
	// }

	// /**
	// *
	// */
	// private void prepareThisPlayerMock(Angle nowRotation,
	// double desiredDistance, Angle desiredRotation, float turnAndRunTime,
	// float alternativeTime, boolean isLeft, float backStepTime)
	// {
	// // the actual coordinates do not matter for position
	// Vector3D position = new Vector3D(0, 10, 0);
	// List<PositionOrientation> positionList = Collections
	// .singletonList(new PositionOrientation(position, desiredRotation));
	// expect(thisPlayerMock.getDesiredPositions()).andStubReturn(positionList);
	// expect(thisPlayerMock.getDistanceToXY(position)).andStubReturn(
	// desiredDistance);
	// expect(thisPlayerMock.getHorizontalAngle()).andReturn(nowRotation);
	// expect(thisPlayerMock.getBodyDirectionTo(position))
	// .andReturn(nowRotation);
	// expect(thisPlayerMock.getTimeToTurnAndRun(position, desiredRotation))
	// .andReturn(turnAndRunTime);
	// expect(
	// thisPlayerMock
	// .getTimeForSideStep(position, desiredRotation, isLeft))
	// .andReturn(alternativeTime);
	// expect(thisPlayerMock.getTimeForBackStep(position, desiredRotation))
	// .andReturn(backStepTime);
	// expect(thisPlayerMock.positionIsLeft(position)).andReturn(isLeft);
	// expect(thisPlayerMock.positionIsRight(position)).andReturn(!isLeft);
	// expect(thisPlayerMock.positionIsBehind(position)).andReturn(true);
	// }

	@Test
	public void testAvoidCollisionBehind()
	{
		Vector3D playerPos = new Vector3D(2, 0, 0);
		Vector3D mePos = new Vector3D(0, 0, 0);
		Vector3D localGoalPos = new Vector3D(-4, 0, 0);
		PositionOrientation localgoalPosOr = new PositionOrientation(
				localGoalPos, Angle.deg(0));

		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		expect(playerMock1.getCollisionDistance()).andStubReturn(0.4);
		obstacles.add(playerMock1);
		// distance to goal position
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				4.0);
		// distance to playerMock1
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				2.0);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		PositionOrientation result = testee.avoidCollision(localgoalPosOr);

		assertSame(localgoalPosOr, result);
	}

	@Test
	public void testAvoidCollisionTooFar()
	{
		Vector3D playerPos = new Vector3D(-2, 0, 0);
		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		obstacles.add(playerMock1);
		expect(thisPlayerMock.getDistanceToXY(goalPos)).andStubReturn(4.0);
		expect(thisPlayerMock.getDistanceToXY(playerPos)).andStubReturn(6.0);
		expect(thisPlayerMock.positionIsBehind(playerPos)).andStubReturn(false);
		replay(worldModelMock, thisPlayerMock, playerMock1);
		PositionOrientation result = testee.avoidCollision(goalPosOr);
		assertSame(goalPosOr, result);
	}

	@Test
	public void testAvoidCollisionTooFarFromLine()
	{
		Vector3D playerPos = new Vector3D(2, 0.5, 0);
		Vector3D mePos = new Vector3D(0, 2.0, 0);
		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		expect(playerMock1.getCollisionDistance()).andStubReturn(0.4);
		obstacles.add(playerMock1);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				4.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				3.0);
		expect(thisPlayerMock.positionIsBehind(playerPos)).andStubReturn(false);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		PositionOrientation result = testee.avoidCollision(goalPosOr);

		assertSame(goalPosOr, result);
	}

	@Test
	public void testAvoidCollisionOtherSideOfOrigin()
	{
		Vector3D playerPos = new Vector3D(2, -1.2, 0);
		Vector3D mePos = new Vector3D(0, -1.0, 0);
		Vector3D localGoalPos = new Vector3D(4, -1.0, 0);
		PositionOrientation localgoalPosOr = new PositionOrientation(
				localGoalPos, Angle.deg(0));

		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		expect(playerMock1.getCollisionDistance()).andStubReturn(0.4);
		obstacles.add(playerMock1);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				4.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				3.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				1.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				1.1);
		expect(thisPlayerMock.positionIsBehind(playerPos)).andStubReturn(false);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		PositionOrientation result = testee.avoidCollision(localgoalPosOr);

		assertEquals(-5.7106, result.getOrientationX().degrees(), 0.0001);
		assertEquals(2.0, result.getPosition().getX(), 0.0001);
		assertEquals(-0.8, result.getPosition().getY(), 0.0001);
	}

	@Test
	public void testAvoidCollisionNeedIntermediate1()
	{
		Vector3D playerPos = new Vector3D(2, 0.1, 0);
		Vector3D mePos = new Vector3D(0, 0, 0);
		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		expect(playerMock1.getCollisionDistance()).andStubReturn(0.4);
		obstacles.add(playerMock1);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				4.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				3.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				1.2);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				1.1);
		expect(thisPlayerMock.positionIsBehind(playerPos)).andStubReturn(false);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		PositionOrientation result = testee.avoidCollision(goalPosOr);

		assertEquals(8.5307, result.getOrientationX().degrees(), 0.0001);
		assertEquals(2.0, result.getPosition().getX(), 0.0001);
		assertEquals(-0.3, result.getPosition().getY(), 0.0001);
	}

	@Test
	public void testAvoidCollisionNeedIntermediate2()
	{
		Vector3D playerPos = new Vector3D(2, -0.1, 0);
		Vector3D mePos = new Vector3D(0, 0, 0);
		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		expect(playerMock1.getCollisionDistance()).andStubReturn(0.4);
		obstacles.add(playerMock1);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				4.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				3.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				1.0);
		expect(thisPlayerMock.getDistanceToXY((Vector3D) anyObject())).andReturn(
				1.1);
		expect(thisPlayerMock.positionIsBehind(playerPos)).andStubReturn(false);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		PositionOrientation result = testee.avoidCollision(goalPosOr);

		assertEquals(-8.5307, result.getOrientationX().degrees(), 0.0001);
		assertEquals(2.0, result.getPosition().getX(), 0.0001);
		assertEquals(0.3, result.getPosition().getY(), 0.0001);
	}

	/*
	 * Test for {@Link RunToPosition#avoidTeammate(Vector3D newPos)}
	 */
	@Test
	public void testAvoidTeammate()
	{
		Vector3D playerPos = new Vector3D(2, -0.1, 0);
		Vector3D newPos = new Vector3D(8, 0, 0);
		Vector3D mePos = new Vector3D(0, 0, 0);
		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		teammatesAtBall.add(playerMock1);
		expect(playerMock1.getDistanceToXY(newPos)).andReturn(0.2);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		Vector3D result = testee.avoidTeammate(newPos);

		assertEquals(7, result.getX(), 0.0001);
		assertEquals(0, result.getY(), 0.0001);
		assertEquals(0, result.getZ(), 0.0001);
	}

	/*
	 * Another Test for {@Link RunToPosition#avoidTeammate(Vector3D newPos)}
	 * Tests what happens one we are near enough already
	 */
	@Test
	public void testAvoidTeammateCloseToNewPos()
	{
		Vector3D playerPos = new Vector3D(2, -0.1, 0);
		Vector3D newPos = new Vector3D(0.9, 0, 0);
		Vector3D mePos = new Vector3D(0, 0, 0);
		expect(playerMock1.getPosition()).andStubReturn(playerPos);
		teammatesAtBall.add(playerMock1);
		expect(playerMock1.getDistanceToXY(newPos)).andReturn(0.2);
		expect(thisPlayerMock.getPosition()).andStubReturn(mePos);
		replay(worldModelMock, thisPlayerMock, playerMock1);

		Vector3D result = testee.avoidTeammate(newPos);

		assertEquals(0, result.getX(), 0.0001);
		assertEquals(0, result.getY(), 0.0001);
		assertEquals(0, result.getZ(), 0.0001);
	}
}
