/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import magma.agent.behavior.positioning.model.IRule;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Test;

public class ActionAreaTest
{
	private IRule rule; // rule to test

	/**
	 * setUp function for every test
	 */
	@Before
	public void setUp()
	{
		rule = new RuleAbsolute();
		List<Double> actionArea = new ArrayList<Double>();
		actionArea.add(-8.0);
		actionArea.add(1.0);
		actionArea.add(7.0);
		actionArea.add(4.0);
		rule.setActionArea(actionArea);
	}

	/**
	 * Test for the positionInArea method.<br>
	 * Position in area.
	 */
	@Test
	public void positionInAreaTest()
	{
		Vector3D position = new Vector3D(-5, 0.5, 90);

		Vector3D finalPosition = rule.positionInArea(position);

		assertEquals(position.getX(), finalPosition.getX(), 0);
		assertEquals(position.getY(), finalPosition.getY(), 0);
	}

	/**
	 * Test for the positionInArea method.<br>
	 * X is negative out of the action area.
	 */
	@Test
	public void xNegativeOutTest()
	{
		Vector3D position = new Vector3D(-8.5, -2, 90);

		Vector3D finalPosition = rule.positionInArea(position);

		assertEquals(rule.getActionArea().get(0), finalPosition.getX(), 0);
		assertEquals(position.getY(), finalPosition.getY(), 0);
	}

	/**
	 * Test for the positionInArea method.<br>
	 * X is positive out of the action area.
	 */
	@Test
	public void xPositiveOutTest()
	{
		Vector3D position = new Vector3D(0, -1, 90);

		Vector3D finalPosition = rule.positionInArea(position);

		assertEquals((rule.getActionArea().get(0) + rule.getActionArea().get(2)),
				finalPosition.getX(), 0);
		assertEquals(position.getY(), finalPosition.getY(), 0);
	}

	/**
	 * Test for the positionInArea method.<br>
	 * Y is negative out of the action area.
	 */
	@Test
	public void yNegativeOutTest()
	{
		Vector3D position = new Vector3D(-5, -4, 90);

		Vector3D finalPosition = rule.positionInArea(position);

		assertEquals(position.getX(), finalPosition.getX(), 0);
		assertEquals(rule.getActionArea().get(1) - rule.getActionArea().get(3),
				finalPosition.getY(), 0);
	}

	/**
	 * Test for the positionInArea method.<br>
	 * Y is positive out of the action area.
	 */
	@Test
	public void yPositiveOutTest()
	{
		Vector3D position = new Vector3D(-5, 5.2, 90);

		Vector3D finalPosition = rule.positionInArea(position);

		assertEquals(position.getX(), finalPosition.getX(), 0);
		assertEquals(rule.getActionArea().get(1), finalPosition.getY(), 0);
	}
}
