/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import static org.easymock.EasyMock.expect;
import static org.easymock.classextension.EasyMock.createMock;
import static org.easymock.classextension.EasyMock.replay;
import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import magma.agent.behavior.positioning.model.IRule;
import magma.agent.worldmodel.IGlobalMap;
import magma.agent.worldmodel.IMoveableObject;
import magma.agent.worldmodel.IPlayer;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Test;

public class RuleLineAbsoluteTest
{
	private IRule rule; // Rule to test

	private IGlobalMap worldModelMock; // Mock for the worldModel

	/**
	 * setUp function for every test
	 */
	@Before
	public void setUp()
	{
		rule = new RuleLineAbsolute();

		List<Double> actionArea = new ArrayList<Double>();
		actionArea.add(-8.0);
		actionArea.add(2.0);
		actionArea.add(7.0);
		actionArea.add(4.0);
		rule.setActionArea(actionArea);

		worldModelMock = createMock(IGlobalMap.class);

		IMoveableObject ballMock = createMock(IMoveableObject.class);

		IPlayer ownPlayerMock = createMock(IPlayer.class);
		List<IPlayer> ownPlayerList = new ArrayList<IPlayer>();
		ownPlayerList.add(ownPlayerMock);

		Vector3D ballPosition = new Vector3D(-5.0, 3.0, 0.0);
		Vector3D ownPlayerPosition = new Vector3D(-9.0, 0.0, 90.0);

		expect(worldModelMock.getBall()).andReturn(ballMock);
		expect(worldModelMock.getVisiblePlayers()).andReturn(ownPlayerList);
		expect(ballMock.getPosition()).andReturn(ballPosition);
		expect(ownPlayerMock.getPosition()).andReturn(ownPlayerPosition);
		expect(ownPlayerMock.getID()).andReturn(1);

		replay(worldModelMock, ballMock, ownPlayerMock);
	}

	/**
	 * Test for the getPosition method.<br>
	 * Reference objects are the own goalkeeper and the ball.
	 */
	@Test
	public void ownGoalieBallLineTest()
	{
		rule.setReferenceObject(1, new ReferenceObjectPlayer(1));
		rule.setReferenceObject(2, new ReferenceObjectBall());

		List<Double> shift = new ArrayList<Double>();
		shift.add(2.0);
		shift.add(90.0);
		rule.setShift(shift);

		Vector3D position = rule.getPosition(worldModelMock);

		Vector3D expectedPosition = new Vector3D(-7.0, 1.5, 90);

		assertEquals(position.getX(), expectedPosition.getX(), 0);
		assertEquals(position.getY(), expectedPosition.getY(), 0);
		assertEquals(position.getZ(), expectedPosition.getZ(), 0);
	}
}
