/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import magma.agent.behavior.positioning.model.IRole;

import org.junit.Before;
import org.junit.Test;

public class SituationTest
{
	private Situation situation; // situation to test

	/**
	 * setUp function for every test
	 */
	@Before
	public void setUp()
	{
		situation = new Situation();
	}

	/**
	 * Test for the setRoles method
	 */
	@Test
	public void setRolesTest()
	{
		List<IRole> roleList = new ArrayList<IRole>();
		roleList.add(new Role("TestRole1", null));
		roleList.add(new Role("TestRole2", null));

		situation.setRoles(roleList);

		assertEquals(roleList, situation.getRoles());
	}

	/**
	 * Test for the getRoles method
	 */
	@Test
	public void getRolesTest()
	{
		List<IRole> roleList = new ArrayList<IRole>();
		roleList.add(new Role("TestRole1", null));
		roleList.add(new Role("TestRole2", null));

		situation.setRoles(roleList);

		List<IRole> roList = situation.getRoles();

		assertEquals("TestRole1", roList.get(0).getRoleName());
		assertEquals("TestRole2", roList.get(1).getRoleName());
	}

	/**
	 * Test for the addRole method
	 */
	@Test
	public void addRoleTest()
	{
		Role role = new Role("TestRole1", null);

		situation.addRole(role);

		List<IRole> roList = situation.getRoles();

		assertEquals("TestRole1", roList.get(0).getRoleName());
	}

	/**
	 * Test for the getRoleByName method
	 */
	@Test
	public void getRoleByNameTest()
	{
		List<IRole> roleList = new ArrayList<IRole>();
		roleList.add(new Role("TestRole1", null));
		roleList.add(new Role("TestRole2", null));
		roleList.add(new Role("TestRole3", null));

		situation.setRoles(roleList);

		assertEquals("TestRole3", situation.getRoleByName("TestRole3")
				.getRoleName());
	}

	/**
	 * Test for the removeRole method
	 */
	@Test
	public void removeRoleTest()
	{
		Role role1 = new Role("TestRole1", null);
		Role role2 = new Role("TestRole2", null);

		situation.addRole(role1);
		situation.addRole(role2);

		situation.removeRole(role1);

		assertEquals(null, situation.getRoleByName("TestRole1"));
	}

	/**
	 * Test for the getRoleByName method.<br>
	 * Try to get a non existent role.
	 */
	@Test
	public void getNonexistentSituationByNameTest()
	{
		Role role1 = new Role("TestRole1", null);
		Role role2 = new Role("TestRole2", null);

		situation.addRole(role1);
		situation.addRole(role2);

		situation.removeRole(role1);

		assertEquals(null, situation.getRoleByName("TestRole1"));
	}

	/**
	 * Test for the addRole method.<br>
	 * Try to add an existent role.
	 */
	@Test
	public void addExistentSituationTest()
	{
		Role role1 = new Role("TestRole1", null);

		situation.addRole(role1);

		assertEquals(false, situation.addRole(role1));
	}

	/**
	 * Test for the removeRole method.<br>
	 * Try to remove a non existent role.
	 */
	@Test
	public void removeNonexistentSituation()
	{
		Role role1 = new Role("TestRole1", null);

		situation.addRole(role1);

		situation.removeRole(role1);

		assertEquals(false, situation.removeRole(role1));
	}
}
