/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.model.impl;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import magma.agent.behavior.positioning.model.ISituation;

import org.junit.Before;
import org.junit.Test;

public class StrategyTest
{
	private Strategy strategy; // strategy to test

	/**
	 * setUp function for every test
	 */
	@Before
	public void setUp()
	{
		strategy = new Strategy();
	}

	/**
	 * Test for the setSituations method
	 */
	@Test
	public void setSituationsTest()
	{
		List<ISituation> situationList = new ArrayList<ISituation>();
		situationList.add(new Situation("TestSituation1", null));
		situationList.add(new Situation("TestSituation2", null));

		strategy.setSituations(situationList);

		assertEquals(situationList, strategy.getSituations());
	}

	/**
	 * Test for the getSituations method
	 */
	@Test
	public void getSituationsTest()
	{
		List<ISituation> situationList = new ArrayList<ISituation>();
		situationList.add(new Situation("TestSituation1", null));
		situationList.add(new Situation("TestSituation2", null));

		strategy.setSituations(situationList);

		List<ISituation> sitList = strategy.getSituations();

		assertEquals("TestSituation1", sitList.get(0).getSituationName());
		assertEquals("TestSituation2", sitList.get(1).getSituationName());
	}

	/**
	 * Test for the addSituation method
	 */
	@Test
	public void addSituationTest()
	{
		ISituation sit = new Situation("TestSituation3", null);

		strategy.addSituation(sit);

		List<ISituation> sitList = strategy.getSituations();

		assertEquals("TestSituation3", sitList.get(0).getSituationName());
	}

	/**
	 * Test for the getSituationByName method
	 */
	@Test
	public void getSituationByNameTest()
	{
		List<ISituation> situationList = new ArrayList<ISituation>();
		situationList.add(new Situation("TestSituation1", null));
		situationList.add(new Situation("TestSituation2", null));
		situationList.add(new Situation("TestSituation3", null));

		strategy.setSituations(situationList);

		assertEquals("TestSituation3",
				strategy.getSituationByName("TestSituation3").getSituationName());
	}

	/**
	 * Test for the removeSituation method
	 */
	@Test
	public void removeSituationTest()
	{
		ISituation sit1 = new Situation("TestSituation1", null);
		ISituation sit2 = new Situation("TestSituation2", null);

		strategy.addSituation(sit1);
		strategy.addSituation(sit2);

		strategy.removeSituation(sit1);

		assertEquals(null, strategy.getSituationByName("TestSituation1"));

	}

	/**
	 * Test for the getSituationByName method.<br>
	 * Try to get a non existent situation.
	 */
	@Test
	public void getNonexistentSituationByNameTest()
	{
		ISituation sit1 = new Situation("TestSituation1", null);
		ISituation sit2 = new Situation("TestSituation2", null);

		strategy.addSituation(sit1);
		strategy.addSituation(sit2);

		strategy.removeSituation(sit1);

		assertEquals(null, strategy.getSituationByName("TestSituation1"));
	}

	/**
	 * Test for the addSituation method.<br>
	 * Try to add an existent situation.
	 */
	@Test
	public void addExistentSituationTest()
	{
		ISituation sit1 = new Situation("TestSituation1", null);

		strategy.addSituation(sit1);

		assertEquals(false, strategy.addSituation(sit1));
	}

	/**
	 * Test for the removeSituation method.<br>
	 * Try to remove a non existent situation.
	 */
	@Test
	public void removeNonexistentSituation()
	{
		ISituation sit1 = new Situation("TestSituation1", null);

		strategy.addSituation(sit1);

		strategy.removeSituation(sit1);

		assertEquals(false, strategy.removeSituation(sit1));
	}

}
