/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.behavior.positioning.xml.impl;

import static org.junit.Assert.assertEquals;

import java.io.File;

import magma.agent.behavior.positioning.model.impl.Strategy;
import magma.agent.behavior.positioning.xml.IXMLWrite;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class XMLFactoryTest
{
	private IXMLWrite xmlFact; // XMLFactory to test

	private static final String dest = "log/strategy.xml"; // Destination of the

	// strategy

	/**
	 * setUp function for every test
	 */
	@Before
	public void setUp()
	{
		xmlFact = new XMLFactory();
	}

	/**
	 * 
	 */
	@Test
	public void createXMLTest()
	{
		Strategy strat = new Strategy("strategy_test", null);

		boolean retVal = xmlFact.createXML(strat, dest);

		Strategy strategy = xmlFact.readXML(dest);

		assertEquals(true, retVal);
		assertEquals("strategy_test", strategy.getStrategyName());
	}

	/**
	 * 
	 */
	@Test
	public void readXMLTest()
	{
		Strategy strat = new Strategy("strategy_test", null);
		xmlFact.createXML(strat, dest);

		Strategy strategy = xmlFact.readXML(dest);

		assertEquals("strategy_test", strategy.getStrategyName());
	}

	/**
	 * 
	 */
	@Test
	public void readXMLFileNotFoundTest()
	{
		Strategy strat = xmlFact.readXML("D:/test/test/");

		assertEquals(null, strat);
	}

	/**
	 * 
	 */
	@Test
	public void deleteXMLTest()
	{
		Strategy strat = new Strategy("strategy_test", null);
		xmlFact.createXML(strat, dest);

		boolean deleted = xmlFact.deleteXML(dest);

		File file = new File(dest);

		assertEquals(true, deleted);
		assertEquals(false, file.exists());
	}

	/**
	 * cleanup methode
	 */
	@After
	public void cleanUp()
	{
		File file = new File(dest);

		if (file.exists()) {
			file.delete();
		}
	}

}
