/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

/**
 * Test case for GameState enum
 * 
 * @author Simon Raffeiner
 */
public class TestGameState
{
	@Test
	public void testdetermineGameStateLeftSide()
	{
		assertEquals(GameState.BEFORE_KICK_OFF, GameState.determineGameState(
				PlayMode.BEFORE_KICK_OFF, PlaySide.LEFT_SIDE));
		assertEquals(GameState.PLAY_ON,
				GameState.determineGameState(PlayMode.PLAY_ON, PlaySide.LEFT_SIDE));
		assertEquals(GameState.GAME_OVER, GameState.determineGameState(
				PlayMode.GAME_OVER, PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_KICK_OFF, GameState.determineGameState(
				PlayMode.KICK_OFF_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_KICK_OFF, GameState.determineGameState(
				PlayMode.KICK_OFF_RIGHT, PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_KICK_IN, GameState.determineGameState(
				PlayMode.KICK_IN_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_KICK_IN, GameState.determineGameState(
				PlayMode.KICK_IN_RIGHT, PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_CORNER_KICK, GameState.determineGameState(
				PlayMode.CORNER_KICK_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_CORNER_KICK,
				GameState.determineGameState(PlayMode.CORNER_KICK_RIGHT,
						PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_FREE_KICK, GameState.determineGameState(
				PlayMode.FREE_KICK_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_FREE_KICK, GameState.determineGameState(
				PlayMode.FREE_KICK_RIGHT, PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_GOAL_KICK, GameState.determineGameState(
				PlayMode.GOAL_KICK_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_GOAL_KICK, GameState.determineGameState(
				PlayMode.GOAL_KICK_RIGHT, PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_OFFSIDE, GameState.determineGameState(
				PlayMode.OFFSIDE_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_OFFSIDE, GameState.determineGameState(
				PlayMode.OFFSIDE_RIGHT, PlaySide.LEFT_SIDE));

		assertEquals(GameState.OWN_GOAL, GameState.determineGameState(
				PlayMode.GOAL_LEFT, PlaySide.LEFT_SIDE));
		assertEquals(GameState.OPPONENT_GOAL, GameState.determineGameState(
				PlayMode.GOAL_RIGHT, PlaySide.LEFT_SIDE));
	}

	@Test
	public void testdetermineGameStateRightSide()
	{
		assertEquals(GameState.BEFORE_KICK_OFF, GameState.determineGameState(
				PlayMode.BEFORE_KICK_OFF, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.PLAY_ON,
				GameState.determineGameState(PlayMode.PLAY_ON, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.GAME_OVER, GameState.determineGameState(
				PlayMode.GAME_OVER, PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_KICK_OFF, GameState.determineGameState(
				PlayMode.KICK_OFF_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_KICK_OFF, GameState.determineGameState(
				PlayMode.KICK_OFF_LEFT, PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_KICK_IN, GameState.determineGameState(
				PlayMode.KICK_IN_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_KICK_IN, GameState.determineGameState(
				PlayMode.KICK_IN_LEFT, PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_CORNER_KICK, GameState.determineGameState(
				PlayMode.CORNER_KICK_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_CORNER_KICK,
				GameState.determineGameState(PlayMode.CORNER_KICK_LEFT,
						PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_FREE_KICK, GameState.determineGameState(
				PlayMode.FREE_KICK_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_FREE_KICK, GameState.determineGameState(
				PlayMode.FREE_KICK_LEFT, PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_GOAL_KICK, GameState.determineGameState(
				PlayMode.GOAL_KICK_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_GOAL_KICK, GameState.determineGameState(
				PlayMode.GOAL_KICK_LEFT, PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_OFFSIDE, GameState.determineGameState(
				PlayMode.OFFSIDE_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_OFFSIDE, GameState.determineGameState(
				PlayMode.OFFSIDE_LEFT, PlaySide.RIGHT_SIDE));

		assertEquals(GameState.OWN_GOAL, GameState.determineGameState(
				PlayMode.GOAL_RIGHT, PlaySide.RIGHT_SIDE));
		assertEquals(GameState.OPPONENT_GOAL, GameState.determineGameState(
				PlayMode.GOAL_LEFT, PlaySide.RIGHT_SIDE));
	}

	@Test
	public void testGameStateNone()
	{
		assertEquals(GameState.NONE,
				GameState.determineGameState(PlayMode.NONE, PlaySide.LEFT_SIDE));
		assertEquals(GameState.NONE,
				GameState.determineGameState(PlayMode.NONE, PlaySide.RIGHT_SIDE));
	}
}
