/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.impl;

import static org.easymock.EasyMock.expect;
import static org.easymock.classextension.EasyMock.createMock;
import static org.easymock.classextension.EasyMock.replay;
import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import magma.agent.agentmodel.IAgentModel;
import magma.agent.agentmodel.IHingeJoint;
import magma.agent.meta.server.impl.RCServerMetaModelV63;
import magma.agent.perception.IPerception;
import magma.agent.perception.IPlayerPos;
import magma.agent.perception.impl.PlayerPos;
import magma.agent.worldmodel.IPlayer;
import magma.robots.nao.INaoConstants;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Test;

/**
 * Tests for the {@link GlobalMap} class
 */
public class GlobalMapTest
{
	private GlobalMap testee;

	private IPerception perceptionMock;

	private IAgentModel agentModelMock;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		perceptionMock = createMock(IPerception.class);
		agentModelMock = createMock(IAgentModel.class);

		testee = new GlobalMap(agentModelMock, null, new RCServerMetaModelV63(),
				"team", 0);
	}

	/**
	 * Test for {@link GlobalMap#updatePlayers(IPerception)}
	 */
	@Test
	public void testUpdatePlayers()
	{
		testee.thisPlayer = new ThisPlayer("self", 0);
		testee.thisPlayer.setPosition(new Vector3D(0.0, 0.0, 0.0));

		// Setup perception
		HashMap<String, Vector3D> bodyPartMap = new HashMap<String, Vector3D>();
		IPlayerPos playerVision = new PlayerPos(new Vector3D(2.0, 3.0, 0.0), 1,
				"test", bodyPartMap);
		List<IPlayerPos> playersVision = new ArrayList<IPlayerPos>();
		playersVision.add(playerVision);
		expect(perceptionMock.containsVision()).andStubReturn(true);
		expect(perceptionMock.getVisiblePlayers()).andStubReturn(playersVision);

		// Setup agent
		IHingeJoint hjMock = createMock(IHingeJoint.class);
		expect(hjMock.getAxis()).andStubReturn(0.0f);
		expect(agentModelMock.getHJ(INaoConstants.NeckYaw)).andStubReturn(hjMock);
		expect(agentModelMock.getHJ(INaoConstants.NeckPitch)).andStubReturn(
				hjMock);

		replay(perceptionMock, agentModelMock, hjMock);

		testee.updatePlayers(perceptionMock);

		List<IPlayer> players = testee.getVisiblePlayers();
		assertEquals(1, players.size());
		IPlayer player = players.get(0);
		assertEquals(1, player.getID());
		assertEquals("test", player.getTeamname());

		// test clear of list if called twice
		testee.updatePlayers(perceptionMock);
		assertEquals(1, testee.getVisiblePlayers().size());

	}
}
