/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.agent.worldmodel.impl;

import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.replay;
import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import magma.agent.worldmodel.IPlayer;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;
import org.junit.Test;

/**
 * Test for the {@link IFOCalculator} class
 * 
 * @author Klaus Dorer
 */
public class IFOCalculatorTest extends WorldModelBaseTest
{
	private IFOCalculator testee;

	private List<IPlayer> sourceList;

	/**
	 * Setup method
	 */
	@Override
	@Before
	public void setUp()
	{
		super.setUp();
		sourceList = new ArrayList<IPlayer>();
		sourceList.add(playerMock1);
		sourceList.add(playerMock2);
		sourceList.add(playerMock3);
		sourceList.add(playerMock4);

		replay(worldModelMock);
		testee = new IFOCalculator(worldModelMock);
	}

	/**
	 * Test for {@link IFOCalculator#getTeammatesAtBall(List)}
	 */
	@Test
	public void getTeammatesAtBall()
	{
		Vector3D ballPosition = new Vector3D(2, 0, 0);
		expect(ballMock.getPosition()).andStubReturn(ballPosition);
		expect(playerMock2.getDistanceToXY(ballPosition)).andStubReturn(1.0);
		expect(playerMock2.isLaying()).andStubReturn(false);
		expect(playerMock4.getDistanceToXY(ballPosition)).andStubReturn(2.0);
		expect(playerMock4.isLaying()).andStubReturn(false);

		replay(thisPlayerMock, playerMock1, playerMock2, playerMock3,
				playerMock4, ballMock);
		List<IPlayer> result = testee.getTeammatesAtBall(sourceList);
		assertEquals(2, result.size());
		assertEquals(playerMock2, result.get(0));
		assertEquals(playerMock4, result.get(1));
	}

	/**
	 * Test for {@link IFOCalculator#getTeammatesAtBall(List)}
	 */
	@Test
	public void getTeammatesAtBallLaying()
	{
		Vector3D ballPosition = new Vector3D(2, 0, 0);
		expect(ballMock.getPosition()).andStubReturn(ballPosition);
		expect(playerMock2.getDistanceToXY(ballPosition)).andStubReturn(1.0);
		expect(playerMock2.isLaying()).andStubReturn(true);
		expect(playerMock4.getDistanceToXY(ballPosition)).andStubReturn(2.0);
		expect(playerMock4.isLaying()).andStubReturn(false);

		replay(thisPlayerMock, playerMock1, playerMock2, playerMock3,
				playerMock4, ballMock);
		List<IPlayer> result = testee.getTeammatesAtBall(sourceList);
		assertEquals(2, result.size());
		assertEquals(playerMock4, result.get(0));
		assertEquals(playerMock2, result.get(1));
	}

}
