/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.impl;

import static org.junit.Assert.assertEquals;
import magma.agent.meta.server.impl.RCServerMetaModelV63;
import magma.agent.worldmodel.IGlobalMap;
import magma.util.SerializationUtil;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Test;

/**
 * Tests for Serialization of global map
 * @author Klaus Dorer
 */
public class SerializationTest
{
	/**
	 * Test for {@link SerializationUtil#doubleSerialize(Object)}
	 * 
	 * @throws Exception In case of fatal error
	 */
	@Test
	public void testBallSerialization() throws Exception
	{
		Vector3D localPos = new Vector3D(1.0, 2.0, 3.0);
		Vector3D globalPos = new Vector3D(4.0, -2.0, 1.0);
		Ball testee = new Ball(.94f);
		testee.update(localPos, globalPos, 1.0f);

		Ball result = (Ball) SerializationUtil.doubleSerialize(testee);
		assertEquals(testee, result);
	}

	/**
	 * Test for {@link SerializationUtil#doubleSerialize(Object)}
	 * 
	 * @throws Exception In case of fatal error
	 */
	@Test
	public void testWorldModelSerialization() throws Exception
	{
		IGlobalMap testee = new GlobalMap(null, null, new RCServerMetaModelV63(),
				"team", 0);
		IGlobalMap result = (IGlobalMap) SerializationUtil
				.doubleSerialize(testee);
		assertEquals(testee, result);
	}
}
