/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.agent.worldmodel.localizer.impl;

import static org.easymock.EasyMock.createMock;
import static org.easymock.EasyMock.expect;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.vecmath.Vector3d;

import magma.agent.meta.server.impl.RCServerMetaModelV62;
import magma.agent.worldmodel.localizer.IEnvironmentModel;
import magma.agent.worldmodel.localizer.ILocalizer;
import magma.agent.worldmodel.localizer.IReferencePoint;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Before;

/**
 * Unit test for {@link magma.agent.worldmodel.localizer.IReferencePoint}
 * 
 * @author Klaus Dorer
 */
public abstract class LocalizerBaseTest
{
	ILocalizer testee;

	IEnvironmentModel environment;

	IReferencePoint G1L;

	IReferencePoint G2L;

	IReferencePoint G1R;

	IReferencePoint G2R;

	IReferencePoint F1L;

	IReferencePoint F2L;

	IReferencePoint F1R;

	IReferencePoint F2R;

	List<IReferencePoint> flags = null;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		Map<String, Vector3d> landmarks = new RCServerMetaModelV62()
				.getLandmarks();
		Vector3d temp;

		G1L = createMock(IReferencePoint.class);
		temp = landmarks.get("G1L");
		expect(G1L.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		G2L = createMock(IReferencePoint.class);
		temp = landmarks.get("G2L");
		expect(G2L.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		G1R = createMock(IReferencePoint.class);
		temp = landmarks.get("G1R");
		expect(G1R.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		G2R = createMock(IReferencePoint.class);
		temp = landmarks.get("G2R");
		expect(G2R.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		F1L = createMock(IReferencePoint.class);
		temp = landmarks.get("F1L");
		expect(F1L.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		F2L = createMock(IReferencePoint.class);
		temp = landmarks.get("F2L");
		expect(F2L.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		F1R = createMock(IReferencePoint.class);
		temp = landmarks.get("F1R");
		expect(F1R.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));

		F2R = createMock(IReferencePoint.class);
		temp = landmarks.get("F2R");
		expect(F2R.getKnownPosition()).andStubReturn(
				new Vector3D(temp.x, temp.y, temp.z));
		flags = new ArrayList<IReferencePoint>();

		environment = createMock(IEnvironmentModel.class);
		expect(environment.getReferencePoints()).andStubReturn(flags);
	}
}
