/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.util;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

import org.apache.commons.math.geometry.Vector3D;
import org.junit.Test;

/**
 * 
 * @author dorer
 */
public class SayCoderTest
{
	/**
	 * Test method for {@link magma.util.SayCoder#encodeID(int)}.
	 */
	@Test
	public void testEncodeID()
	{
		assertEquals("a", SayCoder.encodeID(0));
		assertEquals("b", SayCoder.encodeID(1));
		assertEquals("k", SayCoder.encodeID(10));
	}

	/**
	 * Test method for {@link magma.util.SayCoder#decodeID(java.lang.String)}.
	 */
	@Test
	public void testDecodeID()
	{
		assertEquals(0, SayCoder.decodeID("a"));
		assertEquals(10, SayCoder.decodeID("k"));
	}

	/**
	 * Test method for
	 * {@link magma.util.SayCoder#encodePosition(org.apache.commons.math.geometry.Vector3D)}
	 * .
	 */
	@Test
	public void testEncodePosition()
	{
		assertEquals("323143",
				SayCoder.encodePosition(new Vector3D(12.34, -5.67, 0)));
		assertEquals("200200", SayCoder.encodePosition(new Vector3D(0.0, 0.0, 0)));
	}

	/**
	 * Test method for
	 * {@link magma.util.SayCoder#decodePosition(java.lang.String)}.
	 */
	@Test
	public void testDecodePosition()
	{
		Vector3D result = SayCoder.decodePosition("323143");
		assertEquals(12.3, result.getX(), 0.00001);
		assertEquals(-5.7, result.getY(), 0.00001);

		result = SayCoder.decodePosition("200200");
		assertEquals(0.0, result.getX(), 0.00001);
		assertEquals(0.0, result.getY(), 0.00001);

		assertNull(SayCoder.decodePosition("2a0200"));
		assertNull(SayCoder.decodePosition("2002000"));
	}

	@Test
	public void testEncodeName()
	{
		assertEquals("t", SayCoder.encodeName("magmaOffenburg"));
		assertEquals("e", SayCoder.encodeName("magmaOpponent"));
		assertEquals("p", SayCoder.encodeName("magma"));
		assertEquals("q", SayCoder.encodeName("magmaOpp"));
	}

}
