/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.util.command;

/**
 * Special implementation of the ICommand interface for unit tests
 * 
 * @author Klaus Dorer
 */
public class TestCommand implements ICommand
{
	private final String name;

	private boolean mergeable;

	/**
	 * Constructor
	 * 
	 * @param name Command name
	 */
	public TestCommand(String name)
	{
		this.name = name;
		mergeable = false;
	}

	@Override
	public boolean perform()
	{
		return true;
	}

	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public void undo()
	{
	}

	@Override
	public boolean equals(Object obj)
	{
		return (obj instanceof TestCommand)
				&& name.equals(((TestCommand) obj).name);
	}

	@Override
	public boolean isMergeable(ICommand newCommand)
	{
		return mergeable;
	}

	/**
	 * Set "mergeable" flag, for unit testing only!
	 * 
	 * @param mergeable True if mergeable
	 */
	public void setMergeable(boolean mergeable)
	{
		this.mergeable = mergeable;
	}

	@Override
	public void merge(ICommand newCommand)
	{
	}

	@Override
	public int hashCode()
	{
		return name.hashCode() + super.hashCode();
	}
}
