/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package magma.util.command;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;

/**
 * 
 * @author Klaus Dorer
 */
public class UndoListTest
{
	private UndoList testee;

	private TestCommand command1;

	private ICommand command2;

	private ICommand command3;

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		testee = new UndoList(2);
		command1 = new TestCommand("command1");
		command2 = new TestCommand("command2");
		command3 = new TestCommand("command3");
	}

	/**
	 * Test method for
	 * {@link magma.util.command.UndoList#addCommand(magma.util.command.ICommand)}
	 * .
	 */
	@Test
	public void testAddCommand()
	{
		assertEquals(0, testee.size());
		assertEquals(-1, testee.getUndoIndex());

		testee.addCommand(command1);
		assertEquals(1, testee.size());
		assertEquals(0, testee.getUndoIndex());

		testee.addCommand(command2);
		assertEquals(2, testee.size());

		testee.addCommand(command3);
		assertEquals(2, testee.size());
	}

	/**
	 * Test method for
	 * {@link magma.util.command.UndoList#addCommand(magma.util.command.ICommand)}
	 * .
	 */
	@Test
	public void testAddMergeableCommand()
	{
		command1.setMergeable(true);
		testee.addCommand(command1);
		assertEquals(1, testee.size());

		testee.addCommand(command2);
		assertEquals(1, testee.size());
		assertEquals(0, testee.getUndoIndex());
		assertEquals(command1, testee.getUndoCommand());
	}

	/**
	 * Test method for {@link magma.util.command.UndoList#addCommand(ICommand)}
	 */
	@Test
	public void testAddCommandRemovesLaterInList()
	{
		testee.addCommand(command1);
		testee.addCommand(command2);
		assertEquals(command2, testee.getUndoCommand());
		assertEquals(command1, testee.getUndoCommand());

		testee.addCommand(command3);
		assertEquals(1, testee.size());
		assertEquals(0, testee.getUndoIndex());
	}

	/**
	 * Test method for {@link magma.util.command.UndoList#getUndoCommand()}.
	 */
	@Test
	public void testGetUndoCommand()
	{
		assertEquals(null, testee.getUndoCommand());
		assertEquals(null, testee.getUndoCommand());

		testee.addCommand(command1);
		assertEquals(command1, testee.getUndoCommand());

		testee.addCommand(command1);
		testee.addCommand(command2);
		assertEquals(command2, testee.getUndoCommand());
		assertEquals(command1, testee.getUndoCommand());

		testee.addCommand(command1);
		testee.addCommand(command2);
		testee.addCommand(command3);
		assertEquals(command3, testee.getUndoCommand());
		assertEquals(command2, testee.getUndoCommand());
		assertEquals(null, testee.getUndoCommand());
	}

	/**
	 * Test method for {@link magma.util.command.UndoList#getRedoCommand()}.
	 */
	@Test
	public void testGetRedoCommand()
	{
		assertEquals(null, testee.getRedoCommand());
		assertEquals(null, testee.getRedoCommand());

		testee.addCommand(command1);
		testee.addCommand(command2);
		assertEquals(null, testee.getRedoCommand());
		assertEquals(command2, testee.getUndoCommand());
		assertEquals(command2, testee.getRedoCommand());

		assertEquals(command2, testee.getUndoCommand());
		assertEquals(command1, testee.getUndoCommand());

		ICommand redo = testee.getRedoCommand();
		assertEquals(command1, redo);
		assertEquals("command1", redo.getName());
		assertEquals(true, redo.perform());

		redo = testee.getRedoCommand();
		assertEquals(command2, redo);
		assertEquals("command2", redo.getName());
		assertEquals(true, redo.perform());

		assertEquals(null, testee.getRedoCommand());
	}
}
