/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.function;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

/**
 * @author Klaus Dorer
 * 
 */
public class SinFunctionTest
{
	/**
	 * Create a SinFunction from a CSV string
	 * @return New object
	 */
	private SinFunction createFromCsv()
	{
		String[] params = { "RHipRoll", "sinus", "10.0", "2.51327", "-2.0" };
		return new SinFunction(params, 2.0);
	}

	/**
	 * Create a SinFunction from fixed parameters
	 * 
	 * @return New object
	 */
	private SinFunction createFromParams()
	{
		return new SinFunction(1.5, 8.1, -0.5673, -1.0);
	}

	/**
	 * Test method for {@link magma.util.function.SinFunction#value(double)} .
	 */
	@Test
	public void testValuesCSV()
	{
		SinFunction testee = createFromCsv();

		assertEquals(0.578, testee.value(-2.717), 0.0001);
		assertEquals(3.8778, testee.value(0.0), 0.0001);
		assertEquals(-7.8778, testee.value(5.0), 0.0001);
		assertEquals(-3.8246, testee.value(Math.PI), 0.0001);
	}

	/**
	 * Test method for {@link magma.util.function.SinFunction#value(double)} .
	 */
	@Test
	public void testValuesParams()
	{
		SinFunction testee = createFromParams();

		assertEquals(3.694, testee.value(-2.717), 0.0001);
		assertEquals(-5.3525, testee.value(0.0), 0.0001);
		assertEquals(7.0922, testee.value(5.0), 0.0001);
		assertEquals(-0.791, testee.value(Math.PI), 0.0001);
	}

	/**
	 * Test method for {@link magma.util.function.SinFunction#getName()} .
	 */
	@Test
	public void testGetName()
	{
		SinFunction testee = createFromCsv();
		assertEquals("sinus", testee.getName());
	}

	/**
	 * Test method for {@link magma.util.function.SinFunction#getName()} .
	 */
	@Test
	public void testToCSVString()
	{
		SinFunction testee = createFromCsv();
		assertEquals("sinus,10.0,2.51327,-2.0,", testee.toCSVString());
	}
}
