/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.geometry;

import static org.junit.Assert.assertEquals;

import javax.vecmath.Vector3d;

import org.junit.Test;

/**
 * @author Simon Raffeiner
 * 
 */
public class DenavitHartenbergTest
{
	/**
	 * Test method for
	 * {@link magma.util.geometry.DenavitHartenberg#transform(Vector3d, DenavitHartenbergParameters)}
	 */
	@Test
	public void testTransform()
	{
		Vector3d origin = new Vector3d(2.0, 1.0, 3.0);
		DenavitHartenbergParameters p = new DenavitHartenbergParameters(0, 0, 0,
				new Vector3d(-0.12, -0.005, 0));

		Vector3d result = DenavitHartenberg.transform(origin, p);

		assertEquals(1.88, result.getX(), 0.001);
		assertEquals(0.995, result.getY(), 0.001);
		assertEquals(3.0, result.getZ(), 0.001);

		// Change theta value and try again
		p.setTheta(32.0);
		result = DenavitHartenberg.transform(origin, p);
		assertEquals(1.046, result.getX(), 0.001);
		assertEquals(1.902, result.getY(), 0.001);
		assertEquals(3.0, result.getZ(), 0.001);
	}
}
