/*******************************************************************************
 * Copyright 2008, 2011 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package magma.util.logging;

import static org.junit.Assert.assertEquals;

import java.util.logging.Level;
import java.util.logging.LogRecord;

import org.junit.Before;
import org.junit.Test;

/**
 * Tests for CSV Formatter class
 */
public class PreciseFormatterTest
{
	private PreciseFormatter testee;

	final String lineSeparator = java.security.AccessController
			.doPrivileged(new sun.security.action.GetPropertyAction(
					"line.separator"));

	/**
	 * Setup method
	 */
	@Before
	public void setUp()
	{
		testee = new PreciseFormatter();
	}

	/**
	 * Test serialization of a simple LogRecord message
	 */
	@Test
	public void testFormat()
	{
		LogRecord record = new LogRecord(Level.INFO,
				"This is a test. Please ignore it.");
		record.setMillis(1000000012);

		assertEquals(
				"12.01.1970 14:46:40.12 INFO: This is a test. Please ignore it."
						+ lineSeparator, testee.format(record));
	}

	/**
	 * Test serialization of a more elaborate LogRecord message with an exception
	 */
	@Test
	public void testFormatThrown()
	{
		LogRecord record = new LogRecord(Level.INFO,
				"This is a test. Please ignore it.");
		record.setMillis(1000000012);
		record.setThrown(new RuntimeException());

		assertEquals(
				true,
				testee.format(record)
						.startsWith(
								"12.01.1970 14:46:40.12 INFO: This is a test. Please ignore it."
										+ lineSeparator
										+ "java.lang.RuntimeException"
										+ lineSeparator
										+ "\tat magma.util.logging.PreciseFormatterTest.testFormatThrown"));
	}
}
